<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//no_NB

$LANG=array();


$LANG['backup'][0]="SQL nedlastning"; 
$LANG['backup'][1]="XML nedlastning"; 
$LANG['backup'][11]="Størrelse"; 
$LANG['backup'][13]="Vis/Last ned"; 
$LANG['backup'][16]="Replace the current database with the backup file:"; 
$LANG['backup'][17]="Delete this file"; 
$LANG['backup'][18]="Backup the database"; 
$LANG['backup'][19]="Nå"; 
$LANG['backup'][21]="Fila eksisterer allerede"; 
$LANG['backup'][22]="Kan ikke finne byte"; 
$LANG['backup'][23]="Mysql feil starter ved"; 
$LANG['backup'][24]="Automatisk omdirigering, Else klikk"; 

$LANG['bookmark'][1]="Favoritter"; 
$LANG['bookmark'][2]="Partial load of the bookmark."; 
$LANG['bookmark'][3]="Du har ikke registrert noen bokmerker ennå."; 
$LANG['bookmark'][4]="Nytt bokmerke"; 
$LANG['bookmark'][5]="Offentlig bokmerker"; 
$LANG['bookmark'][6]="Bruk som standard"; 

$LANG['buttons'][0]="Søk"; 
$LANG['buttons'][2]="Ok"; 
$LANG['buttons'][3]="Associate"; 
$LANG['buttons'][4]="Installere"; 
$LANG['buttons'][5]="Avinstallere"; 
$LANG['buttons'][6]="Slett"; 
$LANG['buttons'][7]="Oppdatere"; 
$LANG['buttons'][8]="Legg til"; 
$LANG['buttons'][9]="Kople til"; 
$LANG['buttons'][10]="Frakoble"; 
$LANG['buttons'][11]="Neste"; 
$LANG['buttons'][12]="Forrige"; 
$LANG['buttons'][13]="Tilbake"; 
$LANG['buttons'][14]="Oppdatere"; 
$LANG['buttons'][15]="Planlegge"; 
$LANG['buttons'][16]="Blank"; 
$LANG['buttons'][17]="Invertere valget"; 
$LANG['buttons'][18]="Sjekk Alle"; 
$LANG['buttons'][19]="Fjern alle markeringer"; 
$LANG['buttons'][20]="Flytt"; 
$LANG['buttons'][21]="Gjennopprette"; 
$LANG['buttons'][22]="Utrensing"; 
$LANG['buttons'][23]="Vis"; 
$LANG['buttons'][24]="Gå opp"; 
$LANG['buttons'][25]="Gå ned"; 
$LANG['buttons'][27]="Current page in PDF"; 
$LANG['buttons'][28]="Current page in SLK"; 
$LANG['buttons'][29]="All pages in PDF"; 
$LANG['buttons'][30]="All pages in SLK"; 
$LANG['buttons'][31]="Eksporter"; 
$LANG['buttons'][32]="Avslutte"; 
$LANG['buttons'][33]="Start"; 
$LANG['buttons'][34]="Avbryt"; 
$LANG['buttons'][37]="Importer"; 
$LANG['buttons'][38]="Lås opp"; 
$LANG['buttons'][39]="Erstatte"; 
$LANG['buttons'][40]="Vis Alle"; 
$LANG['buttons'][41]="Aktivere"; 
$LANG['buttons'][42]="Deaktivere"; 
$LANG['buttons'][43]="bla igjennom"; 
$LANG['buttons'][44]="Current page in CSV"; 
$LANG['buttons'][45]="All pages in CSV"; 
$LANG['buttons'][46]="Før"; 
$LANG['buttons'][47]="Etter"; 
$LANG['buttons'][48]="Overføre"; 
$LANG['buttons'][49]="Bevare"; 
$LANG['buttons'][50]="Teste"; 
$LANG['buttons'][51]="Lagre"; 
$LANG['buttons'][52]="Last"; 
$LANG['buttons'][53]="Rense"; 
$LANG['buttons'][55]="Først"; 
$LANG['buttons'][56]="Vare"; 
$LANG['buttons'][57]="Execute"; 
$LANG['buttons'][58]="Update"; 
$LANG['buttons'][59]="Dissociate"; 

$LANG['calendar'][0]="YYYY-MM-DD"; 
$LANG['calendar'][1]="DD-MM-YYYY"; 
$LANG['calendar'][2]="MM-DD-YYYY"; 

$LANG['calendarD'][0]="L"; 
$LANG['calendarD'][1]="M"; 
$LANG['calendarD'][2]="T"; 
$LANG['calendarD'][3]="O"; 
$LANG['calendarD'][4]="T"; 
$LANG['calendarD'][5]="F"; 
$LANG['calendarD'][6]="S"; 

$LANG['calendarDay'][0]="Søndag"; 
$LANG['calendarDay'][1]="Mandag"; 
$LANG['calendarDay'][2]="Tirsdag"; 
$LANG['calendarDay'][3]="Onsdag"; 
$LANG['calendarDay'][4]="Torsdag"; 
$LANG['calendarDay'][5]="Fredag"; 
$LANG['calendarDay'][6]="Lørdag"; 

$LANG['calendarM'][0]="Januar"; 
$LANG['calendarM'][1]="Februar"; 
$LANG['calendarM'][2]="Mars"; 
$LANG['calendarM'][3]="April"; 
$LANG['calendarM'][4]="Mai"; 
$LANG['calendarM'][5]="Juni"; 
$LANG['calendarM'][6]="Juli"; 
$LANG['calendarM'][7]="August"; 
$LANG['calendarM'][8]="September"; 
$LANG['calendarM'][9]="Oktober"; 
$LANG['calendarM'][10]="November"; 
$LANG['calendarM'][11]="Desember"; 

$LANG['cartridges'][0]="Patron"; 
$LANG['cartridges'][7]="Ingen blekkpatron funnet"; 
$LANG['cartridges'][9]="Ingen blekkpatron"; 
$LANG['cartridges'][10]="Toner"; 
$LANG['cartridges'][11]="Ink-Jet"; 
$LANG['cartridges'][12]="Patron Type"; 
$LANG['cartridges'][13]="Ny"; 
$LANG['cartridges'][14]="Brukt"; 
$LANG['cartridges'][15]="Utslitt"; 
$LANG['cartridges'][16]="Patron (er)"; 
$LANG['cartridges'][20]="Ny"; 
$LANG['cartridges'][21]="Brukt"; 
$LANG['cartridges'][22]="Utslitt"; 
$LANG['cartridges'][24]="Legg til dato"; 
$LANG['cartridges'][27]="På"; 
$LANG['cartridges'][29]="Slutt på levetid"; 
$LANG['cartridges'][32]="Modeller av kompatible skrivere"; 
$LANG['cartridges'][33]="Brukte blekkpatroner"; 
$LANG['cartridges'][34]="Ingen ledig blekkpatron"; 
$LANG['cartridges'][35]="Brukte blekkpatroner"; 
$LANG['cartridges'][37]="Sløyfe"; 
$LANG['cartridges'][39]="Printer teller"; 
$LANG['cartridges'][40]="Gjennomsnittlig tid på lager"; 
$LANG['cartridges'][41]="Gjennomsnittlig tid i bruk"; 
$LANG['cartridges'][42]="Gjennomsnittlig antall utskrevne sider"; 

$LANG['central'][2]="Varighet"; 
$LANG['central'][4]="Ingen hendelse"; 
$LANG['central'][5]="Hjem"; 
$LANG['central'][6]="Logg ut"; 
$LANG['central'][7]="Hjelp"; 
$LANG['central'][8]="Utvidelse"; 
$LANG['central'][9]="Dine oppgaver blir behandlet"; 
$LANG['central'][10]="Ny oppgave"; 
$LANG['central'][12]="Persjonelig oversikt"; 
$LANG['central'][13]="Global oversikt"; 
$LANG['central'][14]="Gruppe oversikt"; 
$LANG['central'][18]="Your tickets to close"; 
$LANG['central'][19]="Your tickets to validate"; 

$LANG['choice'][0]="Nei"; 
$LANG['choice'][1]="Ja"; 

$LANG['common'][0]="Uten navn"; 
$LANG['common'][1]="Element"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Show the trash"; 
$LANG['common'][4]="Nett"; 
$LANG['common'][5]="Produsent"; 
$LANG['common'][6]="Mal navn"; 
$LANG['common'][7]="Velg en mal"; 
$LANG['common'][8]="Endre maler"; 
$LANG['common'][9]="Legg til en mal"; 
$LANG['common'][10]="Ansvarlig tekniker"; 
$LANG['common'][11]="Begrenset tilgang"; 
$LANG['common'][12]="Setup"; 
$LANG['common'][13]="Mal"; 
$LANG['common'][14]="Maler"; 
$LANG['common'][15]="Plassering"; 
$LANG['common'][16]="Navn"; 
$LANG['common'][17]="Type"; 
$LANG['common'][18]="Alternate username"; 
$LANG['common'][19]="Serie Nummer"; 
$LANG['common'][20]="Innholdsnummer"; 
$LANG['common'][21]="Alternate username number"; 
$LANG['common'][22]="Modell"; 
$LANG['common'][23]="Operasjon vellykket"; 
$LANG['common'][24]="Ingen valgt element eller dårlig definert operasjon"; 
$LANG['common'][25]="Kommentarer"; 
$LANG['common'][26]="Siste oppdatering"; 
$LANG['common'][27]="Dato"; 
$LANG['common'][28]="Slettet"; 
$LANG['common'][29]="Plug-in"; 
$LANG['common'][30]="Nytt element"; 
$LANG['common'][31]="Tom mal"; 
$LANG['common'][32]="Egenskaper"; 
$LANG['common'][33]="Total"; 
$LANG['common'][34]="Bruker"; 
$LANG['common'][35]="Gruppe"; 
$LANG['common'][36]="Kategori"; 
$LANG['common'][37]="Writer"; 
$LANG['common'][38]="Use unitary management"; 
$LANG['common'][39]="Dupliserte elementet så mange ganger som det er forbindelser"; 
$LANG['common'][40]="Do you really want to use unitary management this item ?"; 
$LANG['common'][41]="E-post alarmer"; 
$LANG['common'][42]="Mobile phone"; 
$LANG['common'][43]="Fornavn"; 
$LANG['common'][44]="Standardverdi (er)"; 
$LANG['common'][45]="MB max"; 
$LANG['common'][46]="Vkort"; 
$LANG['common'][47]="Fremdrift"; 
$LANG['common'][48]="Tilnavn"; 
$LANG['common'][49]="Ingen"; 
$LANG['common'][50]="Confirm the final deletion ?"; 
$LANG['common'][51]="Komplett navn"; 
$LANG['common'][52]="Server"; 
$LANG['common'][53]="Liste"; 
$LANG['common'][54]="Element ikke funnet"; 
$LANG['common'][55]="Er du sikker på at du vil slette det valgte elementet?"; 
$LANG['common'][56]="Standard interface"; 
$LANG['common'][57]="Tittel"; 
$LANG['common'][58]="Maximal verdi"; 
$LANG['common'][59]="Global"; 
$LANG['common'][60]="Aktiv"; 
$LANG['common'][61]="Ukjent feil"; 
$LANG['common'][62]="Annet"; 
$LANG['common'][63]="Feil"; 
$LANG['common'][64]="Direktør"; 
$LANG['common'][65]="Grensesnitt"; 
$LANG['common'][66]="Alle"; 
$LANG['common'][67]="Andre"; 
$LANG['common'][68]="Landskap"; 
$LANG['common'][69]="Portrett"; 
$LANG['common'][70]="Element suksessfullt lagt til"; 
$LANG['common'][71]="Element suksessfullt oppdatert"; 
$LANG['common'][72]="Item successfully deleted"; 
$LANG['common'][73]="Item successfully purged"; 
$LANG['common'][74]="Element suksessfullt gjennopprettet"; 
$LANG['common'][75]="Ingen rett til å gjøre dette elementet Rekursiv i denne enhet"; 
$LANG['common'][76]="Offentlig"; 
$LANG['common'][77]="Privat"; 
$LANG['common'][78]="Sett som offentlig"; 
$LANG['common'][79]="Set personal"; 
$LANG['common'][80]="Under lasting"; 
$LANG['common'][81]="Don't show deleted items"; 
$LANG['common'][82]="MB"; 
$LANG['common'][83]="You don't have permission to perform this action."; 
$LANG['common'][84]="Flagg endre forbudt. Linkede elemtenter funnet."; 
$LANG['common'][85]="Endre synlighet i barnets enheter"; 
$LANG['common'][86]="You are not allowed to change the visibility flag for child entities."; 
$LANG['common'][87]="Nytt kort"; 
$LANG['common'][88]="Personal"; 
$LANG['common'][89]="Not installed"; 
$LANG['common'][90]="Object"; 
$LANG['common'][91]="Can't change this attribute. It's inherited from its parent."; 
$LANG['common'][92]="Alternate username"; 
$LANG['common'][93]="New child heading"; 

$LANG['computers'][0]="Volum"; 
$LANG['computers'][1]="Prosent ledig"; 
$LANG['computers'][2]="Ledig plass"; 
$LANG['computers'][3]="Global størrelse"; 
$LANG['computers'][4]="Fil systèm"; 
$LANG['computers'][5]="Mount point"; 
$LANG['computers'][6]="Partition"; 
$LANG['computers'][7]="Legg til et volum"; 
$LANG['computers'][8]="Volumer"; 
$LANG['computers'][9]="Operating system"; 
$LANG['computers'][10]="Serial of the operating system"; 
$LANG['computers'][11]="Product ID of the operating system"; 
$LANG['computers'][14]="Sett inn"; 
$LANG['computers'][23]="Type of memory"; 
$LANG['computers'][24]="Memory (MB)"; 
$LANG['computers'][25]="Hard drive size"; 
$LANG['computers'][36]="Hard drive type"; 
$LANG['computers'][37]="Ingen tilkoblet skjerm"; 
$LANG['computers'][38]="Ingen tilkoblet skriver"; 
$LANG['computers'][39]="Skrivere"; 
$LANG['computers'][40]="skjerm(er)"; 
$LANG['computers'][46]="Enheter"; 
$LANG['computers'][47]="Ingen tilkoblede enhete"; 
$LANG['computers'][48]="Posisjon er oppdatert. Alle koblede elementer har blitt flyttet til samme posisjon"; 
$LANG['computers'][49]="Alternate username updated. The connected items have been updated using this alternate username."; 
$LANG['computers'][50]="Brukeren eller gruppen er oppdatert. Elementene tilkoblet har blitt flyttet i samme verdier."; 
$LANG['computers'][51]="Oppdateringskilde"; 
$LANG['computers'][52]="Version of the operating system"; 
$LANG['computers'][53]="Service pakke"; 
$LANG['computers'][54]="Ingen telefon tilkoblet"; 
$LANG['computers'][55]="Telefon (er)"; 
$LANG['computers'][56]="Status oppdatert. De tilkoblede elementene har blitt oppdatert ved denne statusen"; 

$LANG['connect'][0]="Direkte tilkoblinger"; 
$LANG['connect'][1]="Ikke tilkoblet"; 
$LANG['connect'][15]="Automatisk oppdatering av følgende elementer"; 
$LANG['connect'][16]="Advarsel! Følgende to elementer av maskinvare samsvarer ikke"; 

$LANG['consumables'][0]="Forbruker"; 
$LANG['consumables'][1]="Grunn"; 
$LANG['consumables'][2]="Henvisning"; 
$LANG['consumables'][7]="Ingen forbruksmateriell funnet"; 
$LANG['consumables'][9]="Ingen forbruker"; 
$LANG['consumables'][12]="Forbruker type"; 
$LANG['consumables'][13]="Ny"; 
$LANG['consumables'][15]="Brukt"; 
$LANG['consumables'][16]="Forbrukere"; 
$LANG['consumables'][20]="Ny"; 
$LANG['consumables'][22]="Brukt"; 
$LANG['consumables'][23]="Status"; 
$LANG['consumables'][26]="Bruks dato"; 
$LANG['consumables'][32]="Gi"; 
$LANG['consumables'][35]="Used consumables"; 
$LANG['consumables'][36]="Lager plassering"; 
$LANG['consumables'][37]="Tilbake til start"; 
$LANG['consumables'][38]="Alert threshold"; 

$LANG['contract'][0]="Contract expired since the"; 
$LANG['contract'][1]="Contract with notice since the"; 

$LANG['crontask'][0]="Automatic actions"; 
$LANG['crontask'][1]="Synchronize equipments from OCSNG"; 
$LANG['crontask'][2]="Send alarms on cartridges"; 
$LANG['crontask'][3]="Send alarms on consumables"; 
$LANG['crontask'][4]="Send alarms on expired licenses"; 
$LANG['crontask'][5]="Send alarms on contracts"; 
$LANG['crontask'][6]="Send alarms on financial information"; 
$LANG['crontask'][7]="Clean old logs"; 
$LANG['crontask'][8]="Database optimization"; 
$LANG['crontask'][9]="Retrieve email (Mail receivers)"; 
$LANG['crontask'][10]="Check the MySQL replica"; 
$LANG['crontask'][11]="Check for new updates"; 
$LANG['crontask'][12]="Clean expired sessions"; 
$LANG['crontask'][13]="Clean generated graphics"; 
$LANG['crontask'][14]="Automatic tickets closing"; 
$LANG['crontask'][15]="Not solved tickets"; 
$LANG['crontask'][31]="Disabled"; 
$LANG['crontask'][32]="Scheduled"; 
$LANG['crontask'][33]="Running"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="Run mode"; 
$LANG['crontask'][37]="Run frequency"; 
$LANG['crontask'][38]="Run period"; 
$LANG['crontask'][39]="Number of email to retrieve"; 
$LANG['crontask'][40]="Last run"; 
$LANG['crontask'][41]="Next run"; 
$LANG['crontask'][42]="As soon as possible"; 
$LANG['crontask'][43]="No action pending"; 
$LANG['crontask'][44]="Action completed, partially processed"; 
$LANG['crontask'][45]="Action completed, fully processed"; 
$LANG['crontask'][46]="Action completed, no processing required"; 
$LANG['crontask'][47]="Last run list"; 
$LANG['crontask'][48]="Start"; 
$LANG['crontask'][50]="Run count"; 
$LANG['crontask'][51]="Minimal time"; 
$LANG['crontask'][52]="Maximal time"; 
$LANG['crontask'][53]="Average time"; 
$LANG['crontask'][55]="Minimal count"; 
$LANG['crontask'][56]="Maximal count"; 
$LANG['crontask'][57]="Average count"; 
$LANG['crontask'][58]="Total count"; 
$LANG['crontask'][59]="Average speed"; 
$LANG['crontask'][60]="System lock"; 
$LANG['crontask'][61]="Disabled plugin"; 
$LANG['crontask'][62]="Elements"; 

$LANG['devices'][0]="Legg til en ny komponent"; 
$LANG['devices'][1]="Harddisk"; 
$LANG['devices'][2]="Grafikk kort"; 
$LANG['devices'][3]="Nettverkskort"; 
$LANG['devices'][4]="Prosessor"; 
$LANG['devices'][5]="System oversikt"; 
$LANG['devices'][6]="Memory"; 
$LANG['devices'][7]="Lydkort"; 
$LANG['devices'][19]="Drivere"; 
$LANG['devices'][20]="Kontroller"; 
$LANG['devices'][21]="Andre komponenter"; 
$LANG['devices'][22]="Tilfeller"; 
$LANG['devices'][23]="Strømforsyning"; 
$LANG['devices'][24]="Som standard"; 
$LANG['devices'][25]="Legg til en komponent"; 
$LANG['devices'][26]="Slett en komponent"; 

$LANG['device_case'][0]="Størrelse"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Skrive evne"; 
$LANG['device_drive'][1]="Fart"; 

$LANG['device_hdd'][0]="Rpm"; 
$LANG['device_hdd'][1]="Depot"; 
$LANG['device_hdd'][4]="Kapasitet"; 

$LANG['device_iface'][0]="Flyt"; 
$LANG['device_iface'][2]="Mac Adresse"; 

$LANG['device_moboard'][0]="Chipset"; 

$LANG['device_power'][0]="Strøm"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Frekvens"; 
$LANG['device_ram'][2]="Størrelse"; 

$LANG['document'][1]="Checksum (SHA1)"; 
$LANG['document'][2]="Fil"; 
$LANG['document'][3]="Overskrift"; 
$LANG['document'][4]="MIME type"; 
$LANG['document'][7]="Dokument type"; 
$LANG['document'][9]="Utvidelse"; 
$LANG['document'][10]="Ikon"; 
$LANG['document'][11]="Autorisert nedlasting"; 
$LANG['document'][15]="Laste ned"; 
$LANG['document'][16]="Legg til dokument"; 
$LANG['document'][18]="Dokument"; 
$LANG['document'][19]="Tilknyttete elementer"; 
$LANG['document'][21]="Tilknyttete dokumenter"; 
$LANG['document'][22]="Gjeldene fil"; 
$LANG['document'][23]="File too large to be added."; 
$LANG['document'][24]="Vellykket sletting av fil"; 
$LANG['document'][25]="Kunne ikke slette filen"; 
$LANG['document'][26]="Filen er gyldig. Opplastingen er vellykket"; 
$LANG['document'][27]="Potensielle opplasting angrep, eller filen for stor. Moving midlertidig fil mislyktes."; 
$LANG['document'][28]="No file specified."; 
$LANG['document'][29]="Kunne ikke opprette registreret"; 
$LANG['document'][30]="Kontroller at du har de riktige tilgangsrettighetene"; 
$LANG['document'][31]="Register for dokumenter finnes ikke"; 
$LANG['document'][32]="Uautorisert filtype"; 
$LANG['document'][33]="Nettlink"; 
$LANG['document'][34]="Opprett katalogen"; 
$LANG['document'][35]="Opplastingsmappa finnes ikke"; 
$LANG['document'][36]="Bruk en FTP installert fil"; 
$LANG['document'][37]="Ingen fil tilgjengelig"; 
$LANG['document'][38]="Fil ikke funnet"; 
$LANG['document'][39]="Dokument fulstendig flyttet"; 
$LANG['document'][40]="Fil flytte mislyktes"; 
$LANG['document'][41]="Dokument fulstendig kopiert"; 
$LANG['document'][42]="Lagt til av"; 
$LANG['document'][43]="Ukjent fil"; 
$LANG['document'][44]="Ugyldig Filnavn"; 
$LANG['document'][45]="Uautorisert tilgang til denne filen"; 
$LANG['document'][46]="Feil i å sende filen (sannsynligvis for stor)"; 
$LANG['document'][48]="A document with that filename has already been attached to (another) record"; 
$LANG['document'][49]="File is altered (bad checksum)"; 
$LANG['document'][50]="Attached items"; 

$LANG['entity'][0]="Enhet"; 
$LANG['entity'][2]="Grunn enhet"; 
$LANG['entity'][3]="Knytt til en enhet"; 
$LANG['entity'][5]="Automatic computer assignment"; 
$LANG['entity'][6]="Automatisk bruker oppdrag"; 
$LANG['entity'][7]="Trestruktur"; 
$LANG['entity'][8]="Ved enhet"; 
$LANG['entity'][9]="Barneservice enheter"; 
$LANG['entity'][10]="Velg ønsket enhet"; 
$LANG['entity'][11]="Se enheter og sub-enheter"; 
$LANG['entity'][12]="LDAP attribute identifying entity"; 
$LANG['entity'][13]="TAG identifying entity"; 
$LANG['entity'][14]="Advanced informations"; 
$LANG['entity'][15]="LDAP directory of an entity"; 
$LANG['entity'][16]="Search filter (if needed)"; 
$LANG['entity'][17]="Automatic closing configuration"; 
$LANG['entity'][18]="Automatic closing of the tickets after"; 

$LANG['event'][0]="Source"; 
$LANG['event'][2]="Service"; 
$LANG['event'][3]="Nivå"; 
$LANG['event'][4]="Melding"; 
$LANG['event'][18]="Felt"; 
$LANG['event'][19]="Oppdatere"; 
$LANG['event'][20]="Ingen historik"; 

$LANG['financial'][1]="Kontrakt"; 
$LANG['financial'][2]="Lever"; 
$LANG['financial'][3]="Finansiell informasjon"; 
$LANG['financial'][4]="Nummer"; 
$LANG['financial'][5]="Kostnad"; 
$LANG['financial'][6]="Kontrakt type"; 
$LANG['financial'][8]="Varighet"; 
$LANG['financial'][9]="År"; 
$LANG['financial'][10]="Notat"; 
$LANG['financial'][11]="Faktura Tidsrom"; 
$LANG['financial'][13]="Kontonummer"; 
$LANG['financial'][14]="Kjøpsdatoen"; 
$LANG['financial'][15]="Warranty duration"; 
$LANG['financial'][16]="Garantiinformasjon"; 
$LANG['financial'][18]="Ordre nummer"; 
$LANG['financial'][19]="Levering form"; 
$LANG['financial'][20]="Sperringsnummer"; 
$LANG['financial'][21]="Verdi"; 
$LANG['financial'][22]="Amortization Type"; 
$LANG['financial'][23]="Amortisering varighet"; 
$LANG['financial'][24]="Legg til kontakt"; 
$LANG['financial'][25]="Legg til leverandør"; 
$LANG['financial'][26]="Leverandør"; 
$LANG['financial'][30]="Telefax"; 
$LANG['financial'][33]="Legg til kontakt"; 
$LANG['financial'][36]="Legg til en kontrakt"; 
$LANG['financial'][42]="Reklame"; 
$LANG['financial'][43]="Tekniker"; 
$LANG['financial'][44]="Adresse"; 
$LANG['financial'][45]="Nettside"; 
$LANG['financial'][46]="Tilknyttede kontakter"; 
$LANG['financial'][47]="Linær"; 
$LANG['financial'][48]="Synkende"; 
$LANG['financial'][50]="Lån"; 
$LANG['financial'][51]="Leie"; 
$LANG['financial'][52]="Leie"; 
$LANG['financial'][53]="Forsikring"; 
$LANG['financial'][54]="Maskinvarestøtte"; 
$LANG['financial'][55]="Programvare support"; 
$LANG['financial'][56]="Service gitt"; 
$LANG['financial'][57]="Måned"; 
$LANG['financial'][59]="Supporttimer"; 
$LANG['financial'][60]="I uka"; 
$LANG['financial'][61]="På Lørdag"; 
$LANG['financial'][62]="Søndager og ferier"; 
$LANG['financial'][65]="Tilknyttede leverandører"; 
$LANG['financial'][66]="Tilknyttede kontrakter"; 
$LANG['financial'][68]="Aktiver finansiell informasjon"; 
$LANG['financial'][69]="Kontrakt periode"; 
$LANG['financial'][76]="Oppstarts dato"; 
$LANG['financial'][77]="Amortisering koeffisient"; 
$LANG['financial'][78]="Garantiservice endene verdi"; 
$LANG['financial'][79]="Tredjepartsprodukter Type"; 
$LANG['financial'][80]="Garanti utløpsdato"; 
$LANG['financial'][81]="Nett konto verdi"; 
$LANG['financial'][82]="Fakturanummer"; 
$LANG['financial'][83]="Max number of items"; 
$LANG['financial'][84]="For denne typen element, finansiell informasjon er bare en modell for de elementene som du bør legge til."; 
$LANG['financial'][85]="Valgte elementet ikke funnet"; 
$LANG['financial'][86]="End of contract"; 
$LANG['financial'][87]="Budsjett"; 
$LANG['financial'][88]="Gyldig til"; 
$LANG['financial'][89]="TCO (verdi + sporingen kostnad)"; 
$LANG['financial'][90]="Månedlig TCO"; 
$LANG['financial'][91]="TCO"; 
$LANG['financial'][92]="ANV"; 
$LANG['financial'][93]="Kontrakt utløpt - varer 30 dager"; 
$LANG['financial'][94]="Kontrakter utløper om mindre en 7 dager"; 
$LANG['financial'][95]="Kontrakter utløper om mindre en 30 dager"; 
$LANG['financial'][96]="Kontrakter hvor varsel begynner på mindre enn 7 dager"; 
$LANG['financial'][97]="Kontrakter hvor varsel begynner på mindre enn 30 dager"; 
$LANG['financial'][98]="Utløpsdato"; 
$LANG['financial'][99]="Utløpsdato + Varsel"; 
$LANG['financial'][100]="Post nr"; 
$LANG['financial'][101]="By"; 
$LANG['financial'][102]="Status"; 
$LANG['financial'][103]="Land"; 
$LANG['financial'][104]="Tilknyttede elementer"; 
$LANG['financial'][105]="Taus"; 
$LANG['financial'][106]="Transportbyrå"; 
$LANG['financial'][107]="Fornyelse"; 
$LANG['financial'][108]="Total spent on the budget"; 
$LANG['financial'][109]="Total remaining on the budget"; 
$LANG['financial'][110]="Budgets"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="Time(er)"; 
$LANG['gmt'][2]="h"; 

$LANG['help'][1]="Matrix of calculus for priority"; 
$LANG['help'][2]="Major"; 
$LANG['help'][3]="Veldig høy"; 
$LANG['help'][4]="Høy"; 
$LANG['help'][5]="Medium"; 
$LANG['help'][6]="Lav"; 
$LANG['help'][7]="Veldig lav"; 
$LANG['help'][8]="Informer meg om handlingen (e) som er gjort"; 
$LANG['help'][11]="min E-Post"; 
$LANG['help'][14]="Send melding"; 
$LANG['help'][16]="If you want be notified about the action(s) taken, please enter your e-mail address."; 
$LANG['help'][18]="Meldingen er sendt,  forespørselen din ligger på filen."; 
$LANG['help'][19]="Takk for at du bruker vårt automatiske helpdesk system."; 
$LANG['help'][22]="Søk IDen til datamaskinen"; 
$LANG['help'][23]="Enter the first letters (user, item name, serial or asset number)"; 
$LANG['help'][24]="Maskinvare Type"; 
$LANG['help'][25]="Datamaskin"; 
$LANG['help'][26]="Nettverk enhet"; 
$LANG['help'][27]="Skriver"; 
$LANG['help'][28]="Monitor"; 
$LANG['help'][29]="Enhet"; 
$LANG['help'][30]="Generelt"; 
$LANG['help'][31]="Programvare"; 
$LANG['help'][35]="Telefon"; 
$LANG['help'][40]="Ingen tittel i billetten, vennligst prøv igjen."; 
$LANG['help'][41]="Ingen kategori i billetten, vennligst prøv igjen."; 
$LANG['help'][42]="Very High"; 
$LANG['help'][43]="High"; 
$LANG['help'][44]="Medium"; 
$LANG['help'][45]="Low"; 
$LANG['help'][46]="Very Low"; 
$LANG['help'][47]="Very High"; 
$LANG['help'][48]="High"; 
$LANG['help'][49]="Medium"; 
$LANG['help'][50]="Low"; 
$LANG['help'][51]="Very Low"; 

$LANG['install'][0]="Installasjon eller oppdatering av GLPI"; 
$LANG['install'][1]="Choose 'Install' for a completely new installation of GLPI."; 
$LANG['install'][2]="Select 'Update' to update your version of GLPI from an earlier version"; 
$LANG['install'][3]="Installasjon"; 
$LANG['install'][4]="Oppdatere"; 
$LANG['install'][5]="Kontroll av kompatibiliteten til miljøet med kjøring av GLPI"; 
$LANG['install'][6]="Test done"; 
$LANG['install'][7]="Resultater"; 
$LANG['install'][8]="Testing PHP parser"; 
$LANG['install'][9]="Du må installere PHP5."; 
$LANG['install'][10]="GLPI er ikke forenlig med muligheten zend.ze1_compatibility_mode = På."; 
$LANG['install'][11]="PHP versjon er minst 5.x - Perfekt!"; 
$LANG['install'][12]="sesjons test"; 
$LANG['install'][13]="PHP-parseren ble ikke utarbeidet med øktene støtte!"; 
$LANG['install'][14]="Sessions er tilgjengelig - Perfekt!"; 
$LANG['install'][15]="Kontroller at øktene støtte er aktivert i din php.ini"; 
$LANG['install'][16]="Sjekker Skrive for dumpfiler"; 
$LANG['install'][17]="Filen kan ikke opprettes."; 
$LANG['install'][18]="Unofficial translations are also available"; 
$LANG['install'][19]="Filen ble opprettet, men kan ikke slettes."; 
$LANG['install'][20]="En fil og en mappe har opprettet og slettet - Perfekt!"; 
$LANG['install'][21]="Sjekker skrive tillatelser for dokumentfiler"; 
$LANG['install'][22]="En fil ble opprettet - Perfekt!"; 
$LANG['install'][23]="Sjekker Skrive for innstillingen filer"; 
$LANG['install'][24]="Initialization of the database"; 
$LANG['install'][25]="Fortsett ?"; 
$LANG['install'][26]="Fortsett"; 
$LANG['install'][27]="Prøv igjen"; 
$LANG['install'][28]="Database forbindelse oppsett"; 
$LANG['install'][29]="Database forbindelse parametere"; 
$LANG['install'][30]="Mysql server"; 
$LANG['install'][31]="Mysql user"; 
$LANG['install'][32]="Mysql password"; 
$LANG['install'][34]="Test av forbindelsen til databasen"; 
$LANG['install'][35]="Kan ikke koble til databasen"; 
$LANG['install'][36]="Serveren svarte"; 
$LANG['install'][37]="The server or/and user field is empty"; 
$LANG['install'][38]="Vennligst velg en database:"; 
$LANG['install'][39]="Opprette en ny database, eller bruk et eksisterende:"; 
$LANG['install'][40]="Velg databasen til oppdatering:"; 
$LANG['install'][41]="Umulig å bruke database:"; 
$LANG['install'][43]="OK - databasen ble initialisert"; 
$LANG['install'][47]="Umulig å skrive databasen installasjonsfilen"; 
$LANG['install'][48]="Feil i å lage database!"; 
$LANG['install'][49]="Du ikke valgt en database!"; 
$LANG['install'][50]="Sjekker Skrive for økt filer"; 
$LANG['install'][52]="Check write permissions for automatic actions files"; 
$LANG['install'][53]="Test av skrive filer av loggen"; 
$LANG['install'][55]="Installasjonen er fulført"; 
$LANG['install'][57]="Default logins / passwords are:"; 
$LANG['install'][58]="glpi / glpi for administratorkonto"; 
$LANG['install'][59]="tech / tech for teknikeren konto"; 
$LANG['install'][60]="normal/normal for the normal account"; 
$LANG['install'][61]="post-only/postonly for the postonly account"; 
$LANG['install'][62]="You can delete or modify these accounts as well as the initial data."; 
$LANG['install'][64]="Bruk GLPI"; 
$LANG['install'][65]="magic_quotes_sybase forlengelse test"; 
$LANG['install'][66]="GLPI fungerer ikke med magic_quotes_sybase alternativet; Vennligst slå den av og prøve på nytt"; 
$LANG['install'][67]="Den magic_quotes_sybase valget er ikke aktive på serveren - Perfekt!"; 
$LANG['install'][68]="Test økt auto start"; 
$LANG['install'][69]="session.auto_start er aktivert. Se. Htaccess fil i GLPI rot for mer informasjon."; 
$LANG['install'][70]="Kan ikke opprette databasen forbindelse fil, venligst bekreft filrettigheter."; 
$LANG['install'][71]="Mysql forlengelsen test."; 
$LANG['install'][72]="Du må kompilere din php med mysql-utvidelsen."; 
$LANG['install'][73]="Ok - funksjonen mysql_query () eksisterer - Perfekt!"; 
$LANG['install'][74]="Test om Session_use_trans_sid brukes"; 
$LANG['install'][75]="Du må descativate den Session_use_trans_id alternativet i php.ini"; 
$LANG['install'][76]="Ok - det økter fungerer (ingen problem med trans_id) - Perfekt!"; 
$LANG['install'][77]="Trinn"; 
$LANG['install'][81]="Starten på installasjonen"; 
$LANG['install'][82]="Database opprettet"; 
$LANG['install'][85]="Funksjonaliteten er funnet - Perfekt!"; 
$LANG['install'][86]="Allokert minne test"; 
$LANG['install'][87]="Allokert minne:"; 
$LANG['install'][88]="Minst 64 MB er vanligvis nødvendig for GLPI."; 
$LANG['install'][89]="Perfekt !"; 
$LANG['install'][90]="Prøve å øke memory_limit parameter i php.ini filen."; 
$LANG['install'][91]="Allokert minne> 64M"; 
$LANG['install'][92]="Lisens"; 
$LANG['install'][93]="Jeg har lest og godtar vilkårene i lisensavtalen skrevet ovenfor."; 
$LANG['install'][94]="Jeg har lest og godtar ikke vilkårene i lisensen skrevet ovenfor"; 
$LANG['install'][95]="Ubegrenset minne"; 
$LANG['install'][96]="Ubegrenset minne"; 
$LANG['install'][97]="Sjekk tillatelser til katalogen:"; 
$LANG['install'][99]="Sjekk  skrive tillatelser for cache-filer"; 
$LANG['install'][100]="Mappen kunne ikke opprettes."; 
$LANG['install'][101]="Katalogen ble opprettet, men kan ikke fjernes."; 
$LANG['install'][102]="Test json funksjoner"; 
$LANG['install'][103]="GLPI kan ikke fungere skikkelig uten json_encode og json_decode funksjoner"; 
$LANG['install'][104]="mbstring extension test"; 
$LANG['install'][105]="Mbstring extension of your parser PHP is not installed"; 
$LANG['install'][106]="Checking write permissions for graphic files"; 

$LANG['job'][2]="Av"; 
$LANG['job'][4]="Ordre"; 
$LANG['job'][5]="Tildelt"; 
$LANG['job'][6]="Tekniker"; 
$LANG['job'][7]="Task"; 
$LANG['job'][8]="last(s) ticket(s)"; 
$LANG['job'][9]="Follow-up"; 
$LANG['job'][11]="Beskriv Problemet/Handlingen"; 
$LANG['job'][12]="Ingen oppfølging for denne oppgaven"; 
$LANG['job'][13]="New ticket"; 
$LANG['job'][15]="Solved"; 
$LANG['job'][19]="Epost oppfølging"; 
$LANG['job'][20]="Total varighet"; 
$LANG['job'][21]="Time(r)"; 
$LANG['job'][22]="Minutter"; 
$LANG['job'][29]="Legg til ny oppfølging"; 
$LANG['job'][30]="Add a new task"; 
$LANG['job'][31]="Varighet"; 
$LANG['job'][32]="Ingen"; 
$LANG['job'][33]="Tom Beskrivelse"; 
$LANG['job'][34]="Plan this task"; 
$LANG['job'][35]="Planlegging"; 
$LANG['job'][37]="Sammendrag"; 
$LANG['job'][38]="Oppgave"; 
$LANG['job'][39]="Oppdater oppfølging"; 
$LANG['job'][40]="Time kostnad"; 
$LANG['job'][41]="Fast pris"; 
$LANG['job'][42]="Material pris"; 
$LANG['job'][43]="Total kostnad"; 
$LANG['job'][44]="Forespørsel kilde"; 
$LANG['job'][45]="Source of follow-up"; 
$LANG['job'][46]="The ticket will be added in the entity"; 
$LANG['job'][47]="Costs"; 
$LANG['job'][48]="Type of solution"; 
$LANG['job'][49]="New task"; 
$LANG['job'][50]="No task for this ticket"; 
$LANG['job'][51]="Approval of the solution"; 
$LANG['job'][52]="Update task"; 
$LANG['job'][53]="Deletion of a task"; 
$LANG['job'][54]="Without a reply, the ticket will be automatically closed after"; 

$LANG['joblist'][0]="Status"; 
$LANG['joblist'][1]="Bare mine"; 
$LANG['joblist'][2]="Prioritet"; 
$LANG['joblist'][3]="Personlig + gruppe (r)"; 
$LANG['joblist'][4]="Tilordnet"; 
$LANG['joblist'][6]="Beskrivelse"; 
$LANG['joblist'][7]="Ny oppgave for denne artikkelen ..."; 
$LANG['joblist'][8]="Ingen oppgave funnet"; 
$LANG['joblist'][9]="Ny"; 
$LANG['joblist'][10]="Stengt (løses)"; 
$LANG['joblist'][11]="Åpnet"; 
$LANG['joblist'][12]="Closed on"; 
$LANG['joblist'][13]="Tickets to be processed"; 
$LANG['joblist'][14]="Solved on"; 
$LANG['joblist'][16]="Ingen oppgave pågår"; 
$LANG['joblist'][17]="Stengt (ikke løses)"; 
$LANG['joblist'][18]="Behandles (tildelte)"; 
$LANG['joblist'][19]="Behandling (planlagt)"; 
$LANG['joblist'][21]="Behandling"; 
$LANG['joblist'][26]="Forestående"; 
$LANG['joblist'][27]="E-post for oppfølging"; 
$LANG['joblist'][28]="Tickets on linked items"; 
$LANG['joblist'][29]="Urgency"; 
$LANG['joblist'][30]="Impact"; 
$LANG['joblist'][32]="Solved"; 
$LANG['joblist'][33]="Closed"; 
$LANG['joblist'][34]="Not solved"; 
$LANG['joblist'][35]="Not closed"; 
$LANG['joblist'][36]="Status value in database"; 

$LANG['jobresolution'][1]="Solution"; 
$LANG['jobresolution'][3]="Approved solution"; 
$LANG['jobresolution'][4]="Refused solution"; 
$LANG['jobresolution'][5]="If you reject the solution, you must specify a reason"; 

$LANG['knowbase'][1]="FAQ"; 
$LANG['knowbase'][5]="Put this item in the FAQ"; 
$LANG['knowbase'][6]="Velg en kategori for dette elementet:"; 
$LANG['knowbase'][7]="Delete this item from the FAQ"; 
$LANG['knowbase'][8]="Rediger dette objektet"; 
$LANG['knowbase'][9]="Slett dette objektet"; 
$LANG['knowbase'][10]="This item is part of the FAQ"; 
$LANG['knowbase'][11]="This item is not part of the FAQ"; 
$LANG['knowbase'][12]="Root"; 
$LANG['knowbase'][13]="Kategori navn"; 
$LANG['knowbase'][14]="Emne"; 
$LANG['knowbase'][15]="Innhold"; 
$LANG['knowbase'][24]="Tilgang til Ofte Stile Spørsmål"; 
$LANG['knowbase'][26]="Visninger"; 
$LANG['knowbase'][27]="På"; 
$LANG['knowbase'][29]="Nylige oppføringer"; 
$LANG['knowbase'][30]="Mest populære spørsmål"; 

$LANG['ldap'][0]="Bulk import users from a LDAP directory"; 
$LANG['ldap'][1]="Synkronisering allerede importert brukere"; 
$LANG['ldap'][2]="Importer nye brukere"; 
$LANG['ldap'][3]="Ingen brukere skal importeres"; 
$LANG['ldap'][4]="LDAP-katalogen valg"; 
$LANG['ldap'][5]="Velg LDAP-katalogen for å importere brukere fra"; 
$LANG['ldap'][6]="Kan ikke koble til LDAP-katalogen"; 
$LANG['ldap'][7]="Ingen LDAP-katalogen er definert i GLPI"; 
$LANG['ldap'][8]="Warning: The request exceeds the limit of the directory. The results are only partial."; 
$LANG['ldap'][9]="Test av tilkobling til LDAP-katalog"; 
$LANG['ldap'][12]="Synkronisering"; 
$LANG['ldap'][13]="in the LDAP directory"; 
$LANG['ldap'][14]="i GLPI"; 
$LANG['ldap'][15]="Synkronisere"; 
$LANG['ldap'][16]="Preconfigurasjon"; 
$LANG['ldap'][17]="Active Directory"; 
$LANG['ldap'][18]="List of LDAP directory replicates"; 
$LANG['ldap'][19]="Repliker"; 
$LANG['ldap'][20]="Add a LDAP directory replica"; 
$LANG['ldap'][21]="Hoved server"; 
$LANG['ldap'][22]="Repliker"; 
$LANG['ldap'][23]="Bulk import groups from a LDAP directory"; 
$LANG['ldap'][24]="Import av nye grupper"; 
$LANG['ldap'][25]="Ingen gruppe som skal importeres"; 
$LANG['ldap'][30]="Hvordan LDAP aliases bør behandles"; 
$LANG['ldap'][31]="Aldri dereferenced (standard)"; 
$LANG['ldap'][32]="Alltid dereferenced"; 
$LANG['ldap'][33]="Dereferenced under søk (men ikke under lokalisering)"; 
$LANG['ldap'][34]="Dereferenced  lokalisering  (ikke under søk)"; 
$LANG['ldap'][35]="Import an user"; 
$LANG['ldap'][36]="No directory associated to entity : search impossible"; 
$LANG['ldap'][38]="Search criterias for users"; 
$LANG['ldap'][39]="Advanced"; 
$LANG['ldap'][40]="Simple"; 
$LANG['ldap'][41]="To change"; 
$LANG['ldap'][42]="No directory selected"; 
$LANG['ldap'][43]="No users to be synchronized"; 
$LANG['ldap'][44]="Default server"; 
$LANG['ldap'][45]="Action when a user is deleted from the LDAP directory"; 
$LANG['ldap'][46]="Withdraw accreditations and groups (dynamics)"; 
$LANG['ldap'][47]="Put in trash"; 
$LANG['ldap'][48]="Deleted user in LDAP directory"; 
$LANG['ldap'][49]="View users added since"; 
$LANG['ldap'][50]="View users updated since"; 
$LANG['ldap'][52]="Less than"; 
$LANG['ldap'][53]="More than"; 
$LANG['ldap'][54]="Enable filtering by date"; 
$LANG['ldap'][55]="Disable filtering by date"; 
$LANG['ldap'][56]="Weeks"; 

$LANG['links'][1]="Link eller Filnavn"; 
$LANG['links'][4]="Hardware type forbundet"; 
$LANG['links'][6]="Valid tags"; 
$LANG['links'][7]="Ingen kobling definert"; 
$LANG['links'][9]="Filinnhold"; 

$LANG['log'][1]="Systemet"; 
$LANG['log'][16]="planlegging"; 
$LANG['log'][18]="komponenter"; 
$LANG['log'][20]="elementet lagt"; 
$LANG['log'][21]="oppdater elementer"; 
$LANG['log'][22]="slette elementet"; 
$LANG['log'][23]="gjenopprette elementet"; 
$LANG['log'][24]="purge element"; 
$LANG['log'][26]="koble fra elementet"; 
$LANG['log'][27]="element forbinnelse"; 
$LANG['log'][28]="modifikasjon av komponenter"; 
$LANG['log'][29]="approval/refusal of the solution"; 
$LANG['log'][30]="knytte en type"; 
$LANG['log'][31]="slette en type"; 
$LANG['log'][32]="add a link with an item"; 
$LANG['log'][33]="slette koblingen med elementet"; 
$LANG['log'][34]="Legge til en kobling med leverandør"; 
$LANG['log'][35]="slette koblingen med leverandør"; 
$LANG['log'][40]="IP-tilkobling"; 
$LANG['log'][41]="tilkobling feilet"; 
$LANG['log'][42]="Reservasjon"; 
$LANG['log'][44]="Overskrift"; 
$LANG['log'][45]="Vellykket"; 
$LANG['log'][46]="Mislyktes"; 
$LANG['log'][48]="Legge til bruker i gruppe"; 
$LANG['log'][49]="slette brukeren fra gruppen"; 
$LANG['log'][55]="Tilkobling"; 
$LANG['log'][59]="Automatic action"; 
$LANG['log'][60]="use unitary management for this item"; 
$LANG['log'][61]="Legge til brukeren til enhet"; 
$LANG['log'][62]="fjerne denne brukeren fullstendig"; 
$LANG['log'][64]="modification of field"; 
$LANG['log'][65]="Regel"; 
$LANG['log'][66]="Sikkerhet"; 
$LANG['log'][67]="modifikasjon av notater"; 
$LANG['log'][70]="nettverksutgang lagt"; 
$LANG['log'][71]="flere nettverksporter lagt"; 
$LANG['log'][73]="nettverksutgang slettet"; 
$LANG['log'][74]="flere nettverksporter slettet"; 
$LANG['log'][75]="nettverksporten flyttet"; 
$LANG['log'][77]="associate a VLAN to a network port"; 
$LANG['log'][78]="associate a VLAN to several ports"; 
$LANG['log'][79]="vlan dissociated from a network port"; 
$LANG['log'][80]="dissociation of a VLAN from multiple network ports"; 
$LANG['log'][82]="legg til versjon"; 
$LANG['log'][83]="modifikasjon av versjoner"; 
$LANG['log'][84]="versjonen er sletting"; 
$LANG['log'][85]="legg til lisens"; 
$LANG['log'][86]="endring av tillatelsen"; 
$LANG['log'][87]="tillatelsen er sletting"; 
$LANG['log'][88]="Legge til toner"; 
$LANG['log'][89]="legge forbruksvarer"; 
$LANG['log'][90]="utelukkelse av en toner"; 
$LANG['log'][91]="utelukkelse av en forbruksmateriell"; 
$LANG['log'][92]="restaurering av en kassett"; 
$LANG['log'][93]="restaurering av en forbruksmateriell"; 
$LANG['log'][94]="kassetten oppdateringsserver"; 
$LANG['log'][95]="toner installasjon"; 
$LANG['log'][96]="patron's avinstallasjonsprosessen"; 
$LANG['log'][97]="forbruksmateriell ut for brukeren"; 
$LANG['log'][98]="add an element"; 
$LANG['log'][99]="modification of an item"; 
$LANG['log'][100]="deletion of an item"; 

$LANG['login'][0]="Siste innlogging"; 
$LANG['login'][1]="Logg inn på nytt"; 
$LANG['login'][2]="LDAP directory"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Ingen tilgang"; 
$LANG['login'][6]="Brukernavn"; 
$LANG['login'][7]="Passord"; 
$LANG['login'][8]="Tom innlogging eller passord"; 
$LANG['login'][9]="Ikke godkjent enda"; 
$LANG['login'][10]="Pålogging"; 
$LANG['login'][11]="Brukeren er ikke autorisert til å koble til GLPI"; 
$LANG['login'][12]="Feil brukernavn eller passord"; 
$LANG['login'][13]="Passord-feltet er tomt"; 
$LANG['login'][14]="ukjent bruker"; 
$LANG['login'][15]="Bruker ikke funnet eller flere brukere funnet"; 
$LANG['login'][16]="mislykkede autorisasjon i LDAP"; 
$LANG['login'][18]="Base interne GLPI"; 
$LANG['login'][20]="Du har ikke tilgang til dette programmet fordi kontoen ble deaktivert eller fjernet"; 
$LANG['login'][21]="Test tilkoblingen til IMAP / POP-serveren"; 
$LANG['login'][22]="Test vellykket"; 
$LANG['login'][23]="Test mislyktes"; 
$LANG['login'][24]="Siste innlogging dato"; 
$LANG['login'][25]="Du har ikke rett til å koble"; 
$LANG['login'][26]="Du må aktivere JavaScript-funksjon av navigator"; 
$LANG['login'][27]="Du må godta cookies for å nå dette programmet"; 
$LANG['login'][30]="Endring av godkjenningsmetoden"; 
$LANG['login'][31]="Authentication on a LDAP directory"; 
$LANG['login'][32]="Godkjenning på GLPI database"; 
$LANG['login'][33]="Godkjenning på IMAP / POP-serveren"; 

$LANG['mailgate'][0]="Mail-mottaker"; 
$LANG['mailgate'][2]="Få E-post oppgaver nå"; 
$LANG['mailgate'][3]="Antall tilgjengelige og hentet e-post"; 
$LANG['mailgate'][4]="mbstring utvidelsen ikke funnet. Advarsel med tegnsettene brukes."; 
$LANG['mailgate'][5]="Ugyldig vedlagte filen"; 
$LANG['mailgate'][6]="For stor vedlagte filen"; 
$LANG['mailgate'][7]="Maximum size of each file imported by the mail receiver"; 
$LANG['mailgate'][9]="Your email could not be processed.\nIf the problem persists, contact the administrator"; 
$LANG['mailgate'][10]="Email refused"; 
$LANG['mailgate'][11]="Process of emails import"; 
$LANG['mailgate'][12]="Unable to affect the email to an entity"; 
$LANG['mailgate'][13]="Reason of rebuff"; 
$LANG['mailgate'][14]="Email not found. Impossible import"; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="======================================================================"; 
$LANG['mailing'][4]="Already done followup(s)"; 
$LANG['mailing'][5]="Beskrivelse av oppgave"; 
$LANG['mailing'][10]="Ny billett oppfølging"; 
$LANG['mailing'][12]="Oppgaven gir"; 
$LANG['mailing'][14]="Oppdatering av kategori oppgaven"; 
$LANG['mailing'][15]="Oppdatering av prioritering av oppgaven"; 
$LANG['mailing'][17]="Oppdatering av elementet av oppgave"; 
$LANG['mailing'][18]="Oppdater forfatteren av oppgaven"; 
$LANG['mailing'][19]="Ny Reservasjon"; 
$LANG['mailing'][20]="Oppdater gruppen for oppgaven"; 
$LANG['mailing'][21]="Change in ticket source"; 
$LANG['mailing'][23]="Antall modifikasjon"; 
$LANG['mailing'][26]="Lagt til dokumentet :"; 
$LANG['mailing'][27]="Oppdatering av status for oppgaven"; 
$LANG['mailing'][29]="Reservasjon Avlyst"; 
$LANG['mailing'][30]="Oppgave Oppdatering"; 
$LANG['mailing'][31]="Dette er en test mail, for å sjekke om E-mail systemet fungerer"; 
$LANG['mailing'][32]="Mail Test"; 
$LANG['mailing'][33]="Cartridges Alarm"; 
$LANG['mailing'][35]="Terskelen for alarmen nås for den type forbruksmateriell:"; 
$LANG['mailing'][36]="Rekvisita Alarm"; 
$LANG['mailing'][37]="Kontrakten er skrevet inn i varsel tid:"; 
$LANG['mailing'][39]="Kontrakt Alarm"; 
$LANG['mailing'][40]="Element kom på slutten av garantien:"; 
$LANG['mailing'][41]="Finans Alarm"; 
$LANG['mailing'][42]="Endring i times kostnader"; 
$LANG['mailing'][43]="Endring i faste kostnader"; 
$LANG['mailing'][44]="Endring i materielle kostnader"; 
$LANG['mailing'][45]="Endre oppgave tittel"; 
$LANG['mailing'][46]="Endre oppgave beskrivelse"; 
$LANG['mailing'][47]="Feil i å sende e-post"; 
$LANG['mailing'][48]="Endring i åpningen dato"; 
$LANG['mailing'][49]="Endring i avsluttende dato"; 
$LANG['mailing'][50]="Endre billett mottaker"; 
$LANG['mailing'][51]="Utløpt lisens:"; 
$LANG['mailing'][53]="Change of solution"; 
$LANG['mailing'][54]="Expiry date"; 
$LANG['mailing'][100]="Ingen definerte kategorien"; 
$LANG['mailing'][101]="Epost-oppfølging er aktivert"; 
$LANG['mailing'][102]="Epost-oppfølging er deaktivert"; 
$LANG['mailing'][104]="Oppfølging varighet"; 
$LANG['mailing'][105]="Ikke tilordnet"; 
$LANG['mailing'][107]="Ingenting"; 
$LANG['mailing'][109]="Ingen gruppe"; 
$LANG['mailing'][110]="Ugyldig e-post"; 
$LANG['mailing'][113]="Notification templates"; 
$LANG['mailing'][114]="Body"; 
$LANG['mailing'][115]="Main part of email"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="text"; 
$LANG['mailing'][118]="Email"; 
$LANG['mailing'][119]="Occurrence"; 
$LANG['mailing'][120]="Notification method"; 
$LANG['mailing'][121]="Recipients"; 
$LANG['mailing'][122]="Task(s) already done"; 
$LANG['mailing'][123]="Solved ticket"; 
$LANG['mailing'][124]="Add a new translation"; 
$LANG['mailing'][125]="Default translation"; 
$LANG['mailing'][126]="Template translation"; 
$LANG['mailing'][127]="Closing of the ticket"; 
$LANG['mailing'][128]="leave the field empty for a generation from HTML"; 
$LANG['mailing'][129]="Deletion of a ticket"; 
$LANG['mailing'][130]="From"; 
$LANG['mailing'][131]="Recipient"; 
$LANG['mailing'][132]="Email header"; 
$LANG['mailing'][133]="Delete email(s)"; 
$LANG['mailing'][134]="Updating follow-up"; 
$LANG['mailing'][135]="Follow-up's deletion"; 
$LANG['mailing'][136]="Reservation expired"; 
$LANG['mailing'][137]="Hardware user"; 
$LANG['mailing'][138]="List of available tags"; 
$LANG['mailing'][139]="Label"; 
$LANG['mailing'][140]="Tag"; 
$LANG['mailing'][141]="Followups"; 
$LANG['mailing'][142]="Tasks"; 
$LANG['mailing'][143]="Validations"; 
$LANG['mailing'][144]="Historical"; 
$LANG['mailing'][145]="List of values"; 
$LANG['mailing'][146]="Single value"; 
$LANG['mailing'][147]="Possible value(s)"; 

$LANG['Menu'][0]="Datamaskiner"; 
$LANG['Menu'][1]="Nettverk"; 
$LANG['Menu'][2]="Skrivere"; 
$LANG['Menu'][3]="Skjermer"; 
$LANG['Menu'][4]="Programvare"; 
$LANG['Menu'][5]="Tickets"; 
$LANG['Menu'][6]="Rapporter"; 
$LANG['Menu'][11]="Instillinger"; 
$LANG['Menu'][12]="Maintenance"; 
$LANG['Menu'][13]="Statistikk"; 
$LANG['Menu'][14]="Brukere"; 
$LANG['Menu'][15]="Administrasjon"; 
$LANG['Menu'][16]="Enheter"; 
$LANG['Menu'][17]="Bestillinger"; 
$LANG['Menu'][18]="Verktøy"; 
$LANG['Menu'][19]="Knowledge base"; 
$LANG['Menu'][20]="FAQ"; 
$LANG['Menu'][21]="Tonere"; 
$LANG['Menu'][22]="Kontakter"; 
$LANG['Menu'][23]="Leverandører"; 
$LANG['Menu'][24]="Finansiell informasjon"; 
$LANG['Menu'][25]="Kontrakter"; 
$LANG['Menu'][26]="Håndtering"; 
$LANG['Menu'][27]="Dokumenter"; 
$LANG['Menu'][28]="Status"; 
$LANG['Menu'][29]="Planlegging"; 
$LANG['Menu'][30]="Logg"; 
$LANG['Menu'][31]="Simplified interface"; 
$LANG['Menu'][32]="Forbruksartikler"; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="Telefoner"; 
$LANG['Menu'][35]="Profiler"; 
$LANG['Menu'][36]="Grupper"; 
$LANG['Menu'][37]="Autorisert"; 
$LANG['Menu'][38]="Utstyrsliste"; 
$LANG['Menu'][39]="Mottaker"; 
$LANG['Menu'][40]="Favoritter"; 
$LANG['Menu'][41]="Rights"; 

$LANG['monitors'][14]="Mikrofon"; 
$LANG['monitors'][15]="Høytalere"; 
$LANG['monitors'][18]="Merknader"; 
$LANG['monitors'][19]="D-sub"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Størrelse"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Pivot"; 

$LANG['networking'][4]="Network port"; 
$LANG['networking'][5]="Memory (MB)"; 
$LANG['networking'][6]="Nettverks port"; 
$LANG['networking'][13]="Nettverks porter funnet"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Koble til"; 
$LANG['networking'][19]="Legg til nettverksport..."; 
$LANG['networking'][21]="Port number"; 
$LANG['networking'][25]="på"; 
$LANG['networking'][37]="networking port(s) found"; 
$LANG['networking'][44]="Porten"; 
$LANG['networking'][46]="Legg til flere porter..."; 
$LANG['networking'][47]="Fra"; 
$LANG['networking'][48]="Til"; 
$LANG['networking'][51]="Nettverks punkt"; 
$LANG['networking'][55]="Knytt til VLAN"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Velg en MAC-adresse i listen eller angi det nedenfor"; 
$LANG['networking'][58]="Dissociate a VLAN"; 
$LANG['networking'][59]="Gateway"; 
$LANG['networking'][60]="Maske"; 
$LANG['networking'][61]="Subnet"; 

$LANG['ocsconfig'][1]="OCSNG database user"; 
$LANG['ocsconfig'][2]="Host for the OCSNG database"; 
$LANG['ocsconfig'][3]="OCSNG user password"; 
$LANG['ocsconfig'][4]="Name of the OCSNG database"; 
$LANG['ocsconfig'][5]="Import Instillinger"; 
$LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Utelat følgende koder (separator $ ingenting for alle)"; 
$LANG['ocsconfig'][10]="Global import"; 
$LANG['ocsconfig'][11]="Ingen import"; 
$LANG['ocsconfig'][12]="Enhet import"; 
$LANG['ocsconfig'][13]="Enhet import: alt er importert 'som den er'"; 
$LANG['ocsconfig'][14]="Global import: alt er importert, men materialet er globalt administreres (uten dobbel blooms)"; 
$LANG['ocsconfig'][15]="Ingen import: plugin vil ikke importere disse elementene"; 
$LANG['ocsconfig'][16]="Standard status"; 
$LANG['ocsconfig'][17]="Begrense importen til følgende koder (separator $ ingenting for alle)"; 
$LANG['ocsconfig'][18]="Kontroller først at duplikatene forvaltes i OCSNG"; 
$LANG['ocsconfig'][19]="Enhet import på serienummer"; 
$LANG['ocsconfig'][27]="Generell informasjon"; 
$LANG['ocsconfig'][36]="Modemer"; 
$LANG['ocsconfig'][37]="Porter"; 
$LANG['ocsconfig'][38]="Use the OCSNG software dictionary"; 
$LANG['ocsconfig'][39]="OCSNG TAG"; 
$LANG['ocsconfig'][40]="Number of items to synchronize via the automatic OCSNG action"; 
$LANG['ocsconfig'][41]="Register"; 
$LANG['ocsconfig'][43]="OCSNG Administrative Information"; 
$LANG['ocsconfig'][48]="Atferd når du kobler fra"; 
$LANG['ocsconfig'][49]="Søppel"; 
$LANG['ocsconfig'][50]="Slettingslogg"; 
$LANG['ocsconfig'][52]="Automatic connection of computers"; 
$LANG['ocsconfig'][53]="Enable the automatic link"; 
$LANG['ocsconfig'][54]="Existence criteria of a computer"; 
$LANG['ocsconfig'][55]="Find computers having the status"; 
$LANG['ocsconfig'][56]="tom"; 
$LANG['ocsconfig'][57]="lik"; 
$LANG['ocsconfig'][58]="The link automatically connects a GLPI computer with one in OCSNG.<br>This option is taken into account during manual link and by synchronization scripts."; 
$LANG['ocsconfig'][59]="Web address of the OCSNG console"; 

$LANG['ocsng'][0]="OCS katalog NG"; 
$LANG['ocsng'][1]="Synkronisete datamaskiner allerede importert"; 
$LANG['ocsng'][2]="Import nye datamaskiner"; 
$LANG['ocsng'][3]="Clean links between GLPI and OCSNG"; 
$LANG['ocsng'][4]="Link nye OCS-maskiner til eksisterende GLPI datamaskiner"; 
$LANG['ocsng'][5]="Import nye datamaskiner"; 
$LANG['ocsng'][6]="Automatisk oppdatering"; 
$LANG['ocsng'][7]="Importert fra OCSNG"; 
$LANG['ocsng'][8]="Import vellykket"; 
$LANG['ocsng'][9]="No new computer to be imported"; 
$LANG['ocsng'][10]="Computers updated in OCSNG"; 
$LANG['ocsng'][11]="Oppdater maskiner"; 
$LANG['ocsng'][12]="No new computer to be updated"; 
$LANG['ocsng'][13]="Import dato i GLPI"; 
$LANG['ocsng'][14]="Last OCSNG inventory date"; 
$LANG['ocsng'][15]="Ingen bane blokkert"; 
$LANG['ocsng'][16]="Lukket Fields"; 
$LANG['ocsng'][18]="Connection to OCSNG database successful"; 
$LANG['ocsng'][19]="Valid OCSNG configuration and version"; 
$LANG['ocsng'][20]="Invalid OCSNG Version: RC3 is required"; 
$LANG['ocsng'][21]="Connection to the OCSNG database failed"; 
$LANG['ocsng'][22]="Forsiktig! Den importerte data (se konfigurasjonen) vil overskrive eksisterende data"; 
$LANG['ocsng'][23]="Unable to import, GLPI computer is already related to an element of OCSNG"; 
$LANG['ocsng'][24]="Force Synkronisering"; 
$LANG['ocsng'][26]="Choice of an OCSNG server"; 
$LANG['ocsng'][27]="No OCSNG server defined"; 
$LANG['ocsng'][29]="OCSNG server"; 
$LANG['ocsng'][30]="Blokkert skjerm"; 
$LANG['ocsng'][32]="Lukket enhet (er)"; 
$LANG['ocsng'][34]="Blokkert skriver"; 
$LANG['ocsng'][36]="Destinasjon enhet"; 
$LANG['ocsng'][37]="Aktiver forhåndsvisning"; 
$LANG['ocsng'][38]="Deaktiver forhåndsvisning"; 
$LANG['ocsng'][40]="Match the rule ?"; 
$LANG['ocsng'][41]="Manuell import modus"; 
$LANG['ocsng'][42]="Invalid OCSNG configuration (TRACE_DELETED must be active)"; 
$LANG['ocsng'][43]="Access denied on OCSNG database (Need write rights on hardware.CHECKSUM necessary)"; 
$LANG['ocsng'][44]="Access denied on OCSNG database (Delete rights in deleted_equiv table necessary)"; 
$LANG['ocsng'][45]="OCS ID"; 
$LANG['ocsng'][46]="Deleted in OCSNG"; 
$LANG['ocsng'][47]="Linked with an OCSNG computer"; 
$LANG['ocsng'][48]="The OCSNG ID of the computer changed"; 
$LANG['ocsng'][49]="Agent"; 
$LANG['ocsng'][50]="Lukket IP (s)"; 
$LANG['ocsng'][52]="Blokkert programvare"; 
$LANG['ocsng'][54]="Software deleted by OCSNG synchronization"; 
$LANG['ocsng'][55]="Volum (er) låst"; 
$LANG['ocsng'][57]="OCSNG Interface"; 

$LANG['pager'][1]="til"; 
$LANG['pager'][2]="fra"; 
$LANG['pager'][3]="av"; 
$LANG['pager'][4]="Vis"; 
$LANG['pager'][5]="enheter"; 

$LANG['peripherals'][18]="Merke"; 
$LANG['peripherals'][31]="Global styring"; 
$LANG['peripherals'][32]="Enhets behandling"; 
$LANG['peripherals'][33]="Behandlingstype"; 

$LANG['phones'][18]="Merke"; 
$LANG['phones'][36]="Strømforsyning"; 
$LANG['phones'][38]="Hodetelefoner"; 
$LANG['phones'][39]="Høytaler"; 
$LANG['phones'][40]="Antal linjer"; 

$LANG['planning'][0]="Den teknikeren valgte allerede har en avtale planlagt for denne timen."; 
$LANG['planning'][1]="Feil på angi datoene. Start datoen er senere enn sluttdato"; 
$LANG['planning'][5]="Dag"; 
$LANG['planning'][6]="Uke"; 
$LANG['planning'][8]="Sporing"; 
$LANG['planning'][9]="Ved"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Download the planning in Ical format"; 
$LANG['planning'][13]="webcal:// synkronisering"; 
$LANG['planning'][14]="Måned"; 
$LANG['planning'][15]="Ditt planlegging"; 
$LANG['planning'][16]="Informasjon"; 
$LANG['planning'][17]="Å gjøre"; 
$LANG['planning'][18]="Ferdig"; 

$LANG['plugins'][0]="Plugins liste"; 
$LANG['plugins'][2]="Installert / ikke konfigurert"; 
$LANG['plugins'][3]="Installert / ikke aktivert"; 
$LANG['plugins'][4]="Feil / å rengjøre"; 
$LANG['plugins'][5]="Fraværende funksjon (er)"; 
$LANG['plugins'][6]="To update"; 
$LANG['plugins'][7]="No plugin installed"; 
$LANG['plugins'][8]="See the catalog of plugins"; 
$LANG['plugins'][9]="Authors"; 
$LANG['plugins'][10]="Incompatible plugin with this version of GLPI"; 

$LANG['printers'][14]="Serial"; 
$LANG['printers'][15]="Parallell"; 
$LANG['printers'][18]="Porter"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="Ethernet"; 
$LANG['printers'][29]="Wifi"; 
$LANG['printers'][30]="Opprinnelig sideteller"; 
$LANG['printers'][31]="Utskrevne sider"; 

$LANG['profiles'][0]="Global høyre"; 
$LANG['profiles'][1]="Entity Høyre"; 
$LANG['profiles'][2]="Profile's interface"; 
$LANG['profiles'][4]="Add a followup to tickets of associated group(s)"; 
$LANG['profiles'][5]="Lag en oppgave"; 
$LANG['profiles'][6]="Add a followup to tickets (requester)"; 
$LANG['profiles'][7]="Vis alle oppgaver"; 
$LANG['profiles'][8]="View all follow-ups and tasks (public and private)"; 
$LANG['profiles'][9]="Show public followups and tasks"; 
$LANG['profiles'][10]="Les"; 
$LANG['profiles'][11]="Skrive"; 
$LANG['profiles'][12]="Ingen tilgang"; 
$LANG['profiles'][13]="Standard Profil"; 
$LANG['profiles'][14]="Slett en oppgave"; 
$LANG['profiles'][15]="Legg til ny oppfølging til alle oppgaver"; 
$LANG['profiles'][16]="Å stå for en oppgave"; 
$LANG['profiles'][17]="Stjel en oppgave"; 
$LANG['profiles'][18]="Oppdater en oppgave"; 
$LANG['profiles'][19]="Tildel oppgave"; 
$LANG['profiles'][20]="Vis personlig planlegging"; 
$LANG['profiles'][21]="View all plannings"; 
$LANG['profiles'][22]="Profil"; 
$LANG['profiles'][23]="Antall Administrasjoner"; 
$LANG['profiles'][24]="Oppdater passord"; 
$LANG['profiles'][26]="Vis opprettede oppgaver i mine grupper"; 
$LANG['profiles'][27]="See hardware of my group(s)"; 
$LANG['profiles'][28]="Rekursiv"; 
$LANG['profiles'][29]="Dynamisk"; 
$LANG['profiles'][30]="Vis OCSNG informasjon"; 
$LANG['profiles'][31]="Synkronisere OCSNG manuelt"; 
$LANG['profiles'][32]="Se tildelt oppgaver (personnal + gruppe tilknyttet)"; 
$LANG['profiles'][33]="Ingen bruker stiftet"; 
$LANG['profiles'][34]="Bildetekst"; 
$LANG['profiles'][35]="Oppdater alle oppfølgninger"; 
$LANG['profiles'][36]="Se tidsplanen til annsatte i mine grupper"; 
$LANG['profiles'][37]="Standard enhet"; 
$LANG['profiles'][38]="Synlighet"; 
$LANG['profiles'][39]="Overdragelse"; 
$LANG['profiles'][40]="Oppdatere"; 
$LANG['profiles'][41]="Fremkalling"; 
$LANG['profiles'][42]="Foreningen"; 
$LANG['profiles'][43]="Autentisering og synkronisering brukere metode"; 
$LANG['profiles'][44]="Change the priority"; 
$LANG['profiles'][45]="Add a task to all tickets"; 
$LANG['profiles'][46]="Edit all tasks"; 
$LANG['profiles'][47]="Add users from an external source"; 
$LANG['profiles'][48]="Create a validation request"; 
$LANG['profiles'][49]="Validate a ticket"; 

$LANG['registry'][1]="Hive"; 
$LANG['registry'][2]="Sti"; 
$LANG['registry'][3]="Nøkkel / verdi"; 
$LANG['registry'][4]="Registernøkkel(er) funnet"; 
$LANG['registry'][5]="Ingen nøkkel funnet i registeret"; 
$LANG['registry'][6]="OCSNG name"; 

$LANG['reminder'][0]="Personlige notater"; 
$LANG['reminder'][1]="Offentlige notater"; 
$LANG['reminder'][6]="Nye notater"; 
$LANG['reminder'][9]="Tekst"; 
$LANG['reminder'][12]="Add to schedule"; 
$LANG['reminder'][15]="Uten tittel"; 
$LANG['reminder'][16]="Globale notater"; 

$LANG['reports'][0]="Velg rapporten du vil generere"; 
$LANG['reports'][4]="Liste over maskinvaren under kontrakt"; 
$LANG['reports'][11]="Maskinvare under kontrakt"; 
$LANG['reports'][12]="Maskinvare Type"; 
$LANG['reports'][13]="Dato (er)"; 
$LANG['reports'][15]="Vis rapport"; 
$LANG['reports'][19]="Alternate username"; 
$LANG['reports'][26]="Standard rapport"; 
$LANG['reports'][27]="Kontrakt"; 
$LANG['reports'][28]="Av året"; 
$LANG['reports'][33]="Nettverks rapport"; 
$LANG['reports'][36]="Tilkoblede enheter"; 
$LANG['reports'][37]="Drops"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="Etter plassering"; 
$LANG['reports'][41]="Av maskinvare"; 
$LANG['reports'][42]="Ved slipp"; 
$LANG['reports'][46]="maskinvare-porter"; 
$LANG['reports'][47]="enhet porter"; 
$LANG['reports'][49]="Network rapporten av maskinvare"; 
$LANG['reports'][51]="Network rapporten ved å slippe"; 
$LANG['reports'][52]="switch"; 
$LANG['reports'][54]="Network rapport etter plassering"; 
$LANG['reports'][57]="Material liste"; 
$LANG['reports'][58]="Equipment's report by year"; 
$LANG['reports'][60]="Åpner dato"; 
$LANG['reports'][61]="Closing date"; 
$LANG['reports'][62]="Hardware Financial Information"; 
$LANG['reports'][63]="Andre Finans (konsesjoner, patroner, forbruksvarer)"; 
$LANG['reports'][64]="Resolution date"; 

$LANG['reservation'][1]="Reserverbare enheter"; 
$LANG['reservation'][2]="Enhet midlertidig utilgjengelig"; 
$LANG['reservation'][3]="Make unavailable"; 
$LANG['reservation'][5]="Make available"; 
$LANG['reservation'][6]="Prohibit reservations"; 
$LANG['reservation'][7]="Authorize reservations"; 
$LANG['reservation'][8]="Bok"; 
$LANG['reservation'][9]="Hold av en gjenstand"; 
$LANG['reservation'][16]="Til"; 
$LANG['reservation'][17]="Fra"; 
$LANG['reservation'][18]="Den nødvendige elementet er allerede reservert for denne tidsrammen"; 
$LANG['reservation'][20]="Back to planning"; 
$LANG['reservation'][21]="See planning"; 
$LANG['reservation'][22]="Endre kommentar"; 
$LANG['reservation'][25]="All reservable hardware"; 
$LANG['reservation'][27]="Øvelse"; 
$LANG['reservation'][28]="Ved uke"; 
$LANG['reservation'][29]="Ved dag"; 
$LANG['reservation'][30]="tider"; 
$LANG['reservation'][31]="Side"; 
$LANG['reservation'][35]="Fremtiden og pågår Reservasjonene"; 
$LANG['reservation'][36]="Tidligere reservasjoner"; 
$LANG['reservation'][37]="Ingen reservasjoner"; 
$LANG['reservation'][38]="Are you sure you want do return this non-reservable item ?"; 
$LANG['reservation'][39]="Dette vil fjerne alle bestillinger pågår"; 
$LANG['reservation'][40]="Material reservations expiring today"; 

$LANG['rulesengine'][0]="er"; 
$LANG['rulesengine'][1]="ikke"; 
$LANG['rulesengine'][2]="inneholder"; 
$LANG['rulesengine'][3]="ikke inneholder"; 
$LANG['rulesengine'][4]="starter med"; 
$LANG['rulesengine'][5]="finished by"; 
$LANG['rulesengine'][6]="Kriterier"; 
$LANG['rulesengine'][7]="Handlinger"; 
$LANG['rulesengine'][8]="Regler ledelse"; 
$LANG['rulesengine'][9]="Logical operator"; 
$LANG['rulesengine'][10]="Position"; 
$LANG['rulesengine'][11]="Handlingstype"; 
$LANG['rulesengine'][12]="Felt"; 
$LANG['rulesengine'][13]="Verdi"; 
$LANG['rulesengine'][14]="Tilstand"; 
$LANG['rulesengine'][15]="Grunn"; 
$LANG['rulesengine'][16]="Kriterier"; 
$LANG['rulesengine'][17]="Regler"; 
$LANG['rulesengine'][18]="Rules for assigning a computer to an entity"; 
$LANG['rulesengine'][19]="Enhet og rettigheter oppdraget regler"; 
$LANG['rulesengine'][20]="Rules applied"; 
$LANG['rulesengine'][21]="Rules applicable in the sub-entities"; 
$LANG['rulesengine'][22]="Tildele"; 
$LANG['rulesengine'][23]="Local rules"; 
$LANG['rulesengine'][24]="Regel type"; 
$LANG['rulesengine'][25]="Computer's name"; 
$LANG['rulesengine'][26]="regular expression checks"; 
$LANG['rulesengine'][27]="regular expression does not match"; 
$LANG['rulesengine'][28]="Business rules for tickets"; 
$LANG['rulesengine'][29]="Liste regler"; 
$LANG['rulesengine'][30]="Handling"; 
$LANG['rulesengine'][33]="Dropdown ordbok"; 
$LANG['rulesengine'][35]="Programvare katalog"; 
$LANG['rulesengine'][36]="Produsentens ordbok"; 
$LANG['rulesengine'][37]="Regler for tildeling av en kategori til programvare"; 
$LANG['rulesengine'][38]="Gjenkalkulere"; 
$LANG['rulesengine'][40]="kategorien"; 
$LANG['rulesengine'][41]="Validitet"; 
$LANG['rulesengine'][42]="OG"; 
$LANG['rulesengine'][43]="ELLER"; 
$LANG['rulesengine'][45]="Assign the value from regular expression"; 
$LANG['rulesengine'][46]="Tilordne: utstyr IP-adresse"; 
$LANG['rulesengine'][47]="Tilordne: utstyr navn + domene"; 
$LANG['rulesengine'][48]="Tilordne utstyr"; 
$LANG['rulesengine'][49]="Tilordne: utstyr MAC-adressen"; 
$LANG['rulesengine'][50]="Datamaskinmodellen ordbok"; 
$LANG['rulesengine'][51]="Monitor modell ordbok"; 
$LANG['rulesengine'][52]="Telefonmodellen ordbok"; 
$LANG['rulesengine'][53]="Utenfor modell ordbok"; 
$LANG['rulesengine'][54]="Skrivermodell ordbok"; 
$LANG['rulesengine'][55]="Nettverk modell ordbok"; 
$LANG['rulesengine'][56]="Modeller"; 
$LANG['rulesengine'][60]="Computer type ordbok"; 
$LANG['rulesengine'][61]="Skjerm type ordbok"; 
$LANG['rulesengine'][62]="Telefon type ordbok"; 
$LANG['rulesengine'][63]="Utenfor Type ordliste"; 
$LANG['rulesengine'][64]="Skrivertype ordbok"; 
$LANG['rulesengine'][65]="Nettverk enhetstypen ordbok"; 
$LANG['rulesengine'][66]="Typer"; 
$LANG['rulesengine'][67]="Operating systems dictionary"; 
$LANG['rulesengine'][68]="Service Pack ordbok"; 
$LANG['rulesengine'][69]="OS versjoner ordbok"; 
$LANG['rulesengine'][70]="Rules for assigning a ticket created through a mail receiver"; 
$LANG['rulesengine'][76]="Replay ordbok"; 
$LANG['rulesengine'][77]="Ordbøker"; 
$LANG['rulesengine'][78]="Versjon"; 
$LANG['rulesengine'][79]="Add the result from regular expression"; 
$LANG['rulesengine'][80]="Global ordbok"; 
$LANG['rulesengine'][81]="Regel resultater"; 
$LANG['rulesengine'][82]="Resultat detaljer"; 
$LANG['rulesengine'][83]="It is possible to affect the result of a regular expression using the string #0"; 
$LANG['rulesengine'][84]="Test maskin regler"; 
$LANG['rulesengine'][85]="Result of the regular expression"; 
$LANG['rulesengine'][86]="Softwarecategory affected when software deleted by dictionary"; 
$LANG['rulesengine'][87]="Software slettet av GLPI ordbok"; 
$LANG['rulesengine'][90]="Arbeid pågår ..."; 
$LANG['rulesengine'][91]="Arbeid utført"; 
$LANG['rulesengine'][92]="Advarsel før du kjører datakatalogen"; 
$LANG['rulesengine'][93]="Warning! This operation can put software in the trash.<br>Sure to notify your users."; 
$LANG['rulesengine'][94]="FUSJON"; 
$LANG['rulesengine'][95]="Produsentens valg"; 
$LANG['rulesengine'][96]="Replay ordlisten for produsenten (e) <br> (----- = All)"; 
$LANG['rulesengine'][97]="Ingen element som skal testes"; 
$LANG['rulesengine'][100]="Cache informasjon"; 
$LANG['rulesengine'][102]="Regel navn"; 
$LANG['rulesengine'][103]="Objekter i cache"; 
$LANG['rulesengine'][104]="Opprinnelige verdien"; 
$LANG['rulesengine'][105]="Forandringer verdi"; 
$LANG['rulesengine'][106]="Uendret"; 
$LANG['rulesengine'][107]="Inaktiv"; 
$LANG['rulesengine'][108]="original"; 
$LANG['rulesengine'][110]="Rettigheter oppdrag"; 
$LANG['rulesengine'][111]="Enheter oppdrag"; 
$LANG['rulesengine'][112]="Rettigheter og enheter oppdrag"; 
$LANG['rulesengine'][120]="Maskinen stopper ved den første skjedde regelen"; 
$LANG['rulesengine'][121]="Motoren behandler alle reglene."; 
$LANG['rulesengine'][122]="Maskinen går resultatet av en regel for følgende seg."; 
$LANG['rulesengine'][130]="Enhet fra LDAP"; 
$LANG['rulesengine'][131]="Enhet fra TAG"; 
$LANG['rulesengine'][132]="To be unaware of import"; 
$LANG['rulesengine'][133]="Entity from domain"; 
$LANG['rulesengine'][134]="Reject email (without email response)"; 
$LANG['rulesengine'][135]="Reject email (with email response)"; 
$LANG['rulesengine'][138]="LDAP criterias"; 
$LANG['rulesengine'][140]="Add a criterium"; 
$LANG['rulesengine'][142]="List of not imported emails"; 
$LANG['rulesengine'][144]="Entity based on user's profile"; 
$LANG['rulesengine'][145]="User with a single profile"; 
$LANG['rulesengine'][146]="User featuring the profile"; 
$LANG['rulesengine'][147]="User featuring a single profile"; 
$LANG['rulesengine'][148]="Mail domain is known"; 
$LANG['rulesengine'][150]="The rules linked with the entity have been disabled."; 

$LANG['search'][0]="Søk"; 
$LANG['search'][1]="for all"; 
$LANG['search'][2]="inneholder"; 
$LANG['search'][4]="sortert etter"; 
$LANG['search'][8]="Start dato"; 
$LANG['search'][9]="Slutt dato"; 
$LANG['search'][10]="i"; 
$LANG['search'][11]="Objekter sett"; 
$LANG['search'][12]="Indicate an ended date"; 
$LANG['search'][15]="Ingen objekter funnet"; 
$LANG['search'][16]="Minst"; 
$LANG['search'][17]="Legg til søkekriterie"; 
$LANG['search'][18]="Slett en søkekriterie"; 
$LANG['search'][19]="Legg til en global søkekriterie"; 
$LANG['search'][20]="Slett en global søkekriterie"; 

$LANG['setup'][0]="Dropdowns"; 
$LANG['setup'][2]="Legg til bruker ..."; 
$LANG['setup'][3]="LDAP directory link"; 
$LANG['setup'][4]="Datamaskin typer"; 
$LANG['setup'][5]="Operativ systemer"; 
$LANG['setup'][6]="Personalisering"; 
$LANG['setup'][9]="Nettverks kort"; 
$LANG['setup'][10]="Display order of surnames firstnames"; 
$LANG['setup'][14]="Email"; 
$LANG['setup'][18]="Login"; 
$LANG['setup'][19]="Password"; 
$LANG['setup'][20]="Password confirmation"; 
$LANG['setup'][21]="Error : the two passwords are not identical"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Etterfulgt privat for standard"; 
$LANG['setup'][40]="Private tasks by default"; 
$LANG['setup'][41]="Velg språk"; 
$LANG['setup'][42]="Nettverk Typer"; 
$LANG['setup'][43]="Printer Typer"; 
$LANG['setup'][44]="Monitor Typer"; 
$LANG['setup'][45]="Sak type"; 
$LANG['setup'][46]="Default value"; 
$LANG['setup'][47]="Default chart format"; 
$LANG['setup'][48]="Default values"; 
$LANG['setup'][62]="Velg kategorien for å konfigurere"; 
$LANG['setup'][63]="Advarsel: Du er i ferd med å fjerne en overskrift som brukes til ett eller flere elementer"; 
$LANG['setup'][64]="If you confirm the deletion the items using this heading used fields will be blanked"; 
$LANG['setup'][65]="Du kan også erstatte alle hendelsene i denne retning av en annen:"; 
$LANG['setup'][67]="Ekstern autentisering"; 
$LANG['setup'][69]="Enheter typer"; 
$LANG['setup'][70]="Generelt oppsett"; 
$LANG['setup'][71]="Firmware"; 
$LANG['setup'][73]="Nettverks punkt"; 
$LANG['setup'][74]="Du kan ikke slette dette stedet, fordi den har sub-plasser"; 
$LANG['setup'][75]="Som barn av"; 
$LANG['setup'][79]="Kategorier av oppgavene"; 
$LANG['setup'][80]="Tredjeparts Type"; 
$LANG['setup'][81]="Dokument overskrifter"; 
$LANG['setup'][82]="Kontakt Type"; 
$LANG['setup'][83]="Element status"; 
$LANG['setup'][84]="Kasett type"; 
$LANG['setup'][85]="Kontrakt type"; 
$LANG['setup'][86]="Type of memory"; 
$LANG['setup'][87]="Knowledge base categories"; 
$LANG['setup'][88]="Nettverk"; 
$LANG['setup'][89]="Domene"; 
$LANG['setup'][90]="VLANs"; 
$LANG['setup'][91]="Datamaskin modeller"; 
$LANG['setup'][92]="Rekvisita Type"; 
$LANG['setup'][93]="Harddisk grensesnitt"; 
$LANG['setup'][94]="Monitor Modeller"; 
$LANG['setup'][95]="Nettverk Modeller"; 
$LANG['setup'][96]="Printer modeller"; 
$LANG['setup'][97]="Perifert Modeller"; 
$LANG['setup'][98]="Tasks category"; 
$LANG['setup'][99]="Building number"; 
$LANG['setup'][100]="Room number"; 
$LANG['setup'][101]="Maximal number of automatic actions (run by CLI)"; 
$LANG['setup'][102]="Logg nivå"; 
$LANG['setup'][103]="1- Critical (login error only)"; 
$LANG['setup'][104]="2 - Alvorlig (ikke brukt)"; 
$LANG['setup'][105]="3- Important (successful logins)"; 
$LANG['setup'][106]="4 - Merknader (Legge til, slette sporing)"; 
$LANG['setup'][107]="5- Ferdig (Alle)"; 
$LANG['setup'][109]="How long system logs are keep in database (in days, 0 for infinite)"; 
$LANG['setup'][110]="Show new tickets on the home page"; 
$LANG['setup'][111]="Maximum number of search results to display on a page"; 
$LANG['setup'][112]="Maximum number of characters for each items in dropdowns"; 
$LANG['setup'][113]="Forhåndsvalg språk"; 
$LANG['setup'][114]="Prioriterte farger"; 
$LANG['setup'][115]="Standard terskel for kassetten og forbruksmateriell teller"; 
$LANG['setup'][116]="Automatisk tildele oppgaver til den tekniske personen som er ansvarlig"; 
$LANG['setup'][117]="Autoriser anonym vising av OSS"; 
$LANG['setup'][118]="Text on the login page"; 
$LANG['setup'][119]="Display"; 
$LANG['setup'][120]="Use dynamic display for dropdowns and text fields"; 
$LANG['setup'][121]="Character to force the full display of dropdowns (wildcard)"; 
$LANG['setup'][122]="Maximum number of items to display in the dropdowns when wildcard is not used"; 
$LANG['setup'][123]="Don't use dynamic display if the number of items is less than"; 
$LANG['setup'][124]="Automatisk legge til brukere av den autentiserte kilden"; 
$LANG['setup'][125]="... Fra ekstern kilde"; 
$LANG['setup'][126]="Automatisk legg til en bruker av en ekstern kilde"; 
$LANG['setup'][127]="Autocompletion of text fields"; 
$LANG['setup'][128]="Dato Format"; 
$LANG['setup'][129]="Show GLPI ID"; 
$LANG['setup'][130]="Number of days this action logs are stored"; 
$LANG['setup'][132]="Display the complete name in the tree dropdowns"; 
$LANG['setup'][133]="Aktiver OCSNG modus"; 
$LANG['setup'][134]="OCSNG tilstand"; 
$LANG['setup'][135]="Normal"; 
$LANG['setup'][136]="Oversettelse"; 
$LANG['setup'][137]="Feilsøke"; 
$LANG['setup'][138]="Bruk GLPI i modus"; 
$LANG['setup'][139]="Vanlig"; 
$LANG['setup'][140]="Typer"; 
$LANG['setup'][145]="Os"; 
$LANG['setup'][147]="Dynamic display"; 
$LANG['setup'][148]="Trinn for timer"; 
$LANG['setup'][149]="Antall desimaler i mengder"; 
$LANG['setup'][150]="Tallformat"; 
$LANG['setup'][154]="Basedn"; 
$LANG['setup'][155]="rootdn (for ikke anonyme binder)"; 
$LANG['setup'][156]="Pass (for ikke-anonym binder)"; 
$LANG['setup'][157]="LDAP forlengelse av PHP-parseren er ikke installert"; 
$LANG['setup'][158]="Umulig å bruke LDAP som ekstern kilde for tilkobling"; 
$LANG['setup'][159]="Tilkoblings filter"; 
$LANG['setup'][162]="IMAP / POP-konfigurasjon"; 
$LANG['setup'][164]="IMAP/POP Host Name <br>(users email will be login@thishost)"; 
$LANG['setup'][165]="PHP-parser ble utarbeidet uten IMAP-funksjoner"; 
$LANG['setup'][166]="Umulig å bruke IMAP / POP som ekstern kilde for tilkobling"; 
$LANG['setup'][167]="LDAP directory / GLPI links"; 
$LANG['setup'][168]="Tilkoblings instillinger"; 
$LANG['setup'][169]="Mail folder (optional, often INBOX)"; 
$LANG['setup'][170]="Connection string"; 
$LANG['setup'][171]="Port (valgfritt)"; 
$LANG['setup'][172]="Port (default=389)"; 
$LANG['setup'][174]="CAS vert"; 
$LANG['setup'][175]="Port"; 
$LANG['setup'][176]="Rotkatalogen (valgfritt)"; 
$LANG['setup'][177]="CAS konfigurasjon"; 
$LANG['setup'][178]="CURL eller DOMXML utvidelsen for PHP pareseren er ikke installert"; 
$LANG['setup'][179]="Umulig å bruke CAS som ekstern kilde for tilkobling"; 
$LANG['setup'][180]="Bruk TLS"; 
$LANG['setup'][181]="ldap_start_tls eksisterer ikke"; 
$LANG['setup'][182]="Logout fallback URL"; 
$LANG['setup'][185]="Logs in files (SQL, email, automatic action...)"; 
$LANG['setup'][186]="Tids sone"; 
$LANG['setup'][190]="x509 sertifikat"; 
$LANG['setup'][191]="E-post egenskap for x509"; 
$LANG['setup'][192]="Aktivert"; 
$LANG['setup'][193]="Field holding the login in the _SERVER array"; 
$LANG['setup'][194]="Additional informations retrieval from LDAP directory"; 
$LANG['setup'][195]="Hold status"; 
$LANG['setup'][196]="Clear status"; 
$LANG['setup'][197]="Kopier datamaskin status"; 
$LANG['setup'][198]="Angi status"; 
$LANG['setup'][199]="Remove the domain of login in form login@domain"; 
$LANG['setup'][200]="Infinite"; 
$LANG['setup'][201]="Alert and email followups configuration"; 
$LANG['setup'][202]="Enable Follow-up via email"; 
$LANG['setup'][203]="Administrator E-post"; 
$LANG['setup'][204]="E-Post signatur"; 
$LANG['setup'][205]="E-post er sendt til administrator"; 
$LANG['setup'][206]="Mislyktes i og sende e-post til administrator"; 
$LANG['setup'][207]="Administrator svar til e-post (om nødvendig)"; 
$LANG['setup'][217]="PHP-post-funksjonen er ukjent eller ikke er aktivert på systemet"; 
$LANG['setup'][218]="Bruken av SMTP er nødvendig"; 
$LANG['setup'][219]="Allow anonymous ticket creation (helpdesk.receiver)"; 
$LANG['setup'][221]="Beginning of fiscal year"; 
$LANG['setup'][223]="Grensen av tilleggene for planlegging"; 
$LANG['setup'][227]="URL of the application"; 
$LANG['setup'][228]="Login Field"; 
$LANG['setup'][229]="Send a test email to the administrator"; 
$LANG['setup'][231]="Bruk en SMTP-server for å sende e-post"; 
$LANG['setup'][232]="SMTP Host"; 
$LANG['setup'][234]="SMTP Login (optional)"; 
$LANG['setup'][235]="SMTP Passord"; 
$LANG['setup'][236]="Tidligere tekniker med ansvar for oppgaven"; 
$LANG['setup'][237]="Administrator"; 
$LANG['setup'][239]="Tekniker med ansvar for denne oppgaven"; 
$LANG['setup'][240]="Varslingsalternativer"; 
$LANG['setup'][241]="Ingen personlige kriterier. Lag personlige parametere?"; 
$LANG['setup'][242]="Alarm instillinger"; 
$LANG['setup'][243]="Alarmer på forbruksvarer"; 
$LANG['setup'][244]="Alarmer på kassetter"; 
$LANG['setup'][245]="Reminders frequency"; 
$LANG['setup'][246]="Alarmer på kontrakter"; 
$LANG['setup'][247]="Alarmer på finansiell informasjon"; 
$LANG['setup'][248]="Gruppen som har ansvaret for oppgaven"; 
$LANG['setup'][249]="Etterspørsels gruppe"; 
$LANG['setup'][250]="Standard søkefelt listen"; 
$LANG['setup'][252]="Velg standard elementer som skal vises"; 
$LANG['setup'][253]="Filter for å søke i grupper"; 
$LANG['setup'][254]="Søketype"; 
$LANG['setup'][255]="Gruppe egenskapene innholder brukerne"; 
$LANG['setup'][256]="I brukere"; 
$LANG['setup'][257]="I grupper"; 
$LANG['setup'][258]="Brukere & grupper"; 
$LANG['setup'][259]="Tilhørighet til grupper"; 
$LANG['setup'][260]="Bruker attributten inneholder sine grupper"; 
$LANG['setup'][261]="Gruppe DN"; 
$LANG['setup'][262]="Bruk DN i søket"; 
$LANG['setup'][263]="Søk filter for brukere"; 
$LANG['setup'][264]="Alarm for utgått lisens"; 
$LANG['setup'][271]="Begrens overvåkings administrasjon"; 
$LANG['setup'][272]="Begrens enhets behandlingsserver"; 
$LANG['setup'][273]="Begrens telefonen administrasjon"; 
$LANG['setup'][274]="for og legge til manuelt"; 
$LANG['setup'][275]="Begrens skriver administrasjon"; 
$LANG['setup'][280]="Automatically update of the elements related to the computers"; 
$LANG['setup'][281]="When connecting or updating"; 
$LANG['setup'][282]="When disconnecting"; 
$LANG['setup'][283]="Kopier"; 
$LANG['setup'][284]="Fjern"; 
$LANG['setup'][285]="Do not copy"; 
$LANG['setup'][286]="Do not delete"; 
$LANG['setup'][300]="Se etter om en ny verson er tilgjengelig"; 
$LANG['setup'][301]="En ny versjon er tilgjengelig:"; 
$LANG['setup'][302]="Du finner den på GLPI-PROJECT.org nettsted"; 
$LANG['setup'][303]="Du har siste oppdaterte versjon"; 
$LANG['setup'][304]="Tilkoblingen mislyktes, om du bruker en proxy må du konfigurere denne"; 
$LANG['setup'][305]="Hver dag"; 
$LANG['setup'][306]="Sjekk for oppgradering"; 
$LANG['setup'][307]="Aldri"; 
$LANG['setup'][308]="Hver uke"; 
$LANG['setup'][309]="Hver måned"; 
$LANG['setup'][310]="Umulig å koble til nettstedet."; 
$LANG['setup'][311]="Mislyktes i og koble til proxy servern"; 
$LANG['setup'][312]="Ingen data tilgjengelig på nettstedet"; 
$LANG['setup'][313]="Be careful : there is no default value"; 
$LANG['setup'][350]="Link med elementer for etableringen av oppgaver"; 
$LANG['setup'][351]="Alle gjenstander"; 
$LANG['setup'][352]="Linkbare elementer til en oppgave"; 
$LANG['setup'][360]="Automatisk felt (merket med *)"; 
$LANG['setup'][400]="Proxy configuration"; 
$LANG['setup'][407]="Simplified interface help link"; 
$LANG['setup'][408]="Standard interface help link"; 
$LANG['setup'][409]="Standard overskrift når du legger ett dokument til en oppgave"; 
$LANG['setup'][503]="Telefoner modeller"; 
$LANG['setup'][504]="Telefoner Typer"; 
$LANG['setup'][505]="Strømforsyning type telefoner"; 
$LANG['setup'][601]="LDAP Verdi"; 
$LANG['setup'][602]="Tilkobling til OCSNG databasen"; 
$LANG['setup'][603]="Legg til en bruker"; 
$LANG['setup'][604]="Knytt til en gruppe"; 
$LANG['setup'][606]="Kan ikke legge til. Brukeren finnes allerede."; 
$LANG['setup'][607]="Knytt til en profil"; 
$LANG['setup'][608]="Software associable to a ticket by default"; 
$LANG['setup'][609]="Unable to add. The OCSNG server already exists."; 
$LANG['setup'][610]="Obligatorisk tittel av oppgaven"; 
$LANG['setup'][611]="Obligatoriske oppgaver sitt innhold"; 
$LANG['setup'][612]="Obligatoriske oppgaver kategorien"; 
$LANG['setup'][613]="Add a user who have no accreditation from a LDAP directory"; 
$LANG['setup'][614]="Unable to update login. A user already exists."; 
$LANG['setup'][615]="Life cycle of tickets"; 
$LANG['setup'][616]="From \ To"; 
$LANG['setup'][620]="Link"; 
$LANG['setup'][621]="Search filter for entities"; 
$LANG['setup'][622]="Attribute representing entity"; 
$LANG['setup'][623]="Import entities from LDAP directory"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="Mail server"; 
$LANG['setup'][661]="Impossible to configure the notifications : please enable email monitoring"; 
$LANG['setup'][703]="General"; 
$LANG['setup'][704]="Varsler"; 
$LANG['setup'][707]="Alerts on reservations"; 
$LANG['setup'][708]="Alerts on tickets which are not solved since"; 
$LANG['setup'][720]="System informations"; 
$LANG['setup'][721]="Information about system installation and configuration"; 
$LANG['setup'][722]="To copy/paste in your support request"; 
$LANG['setup'][731]="Value of the global configuration"; 
$LANG['setup'][732]="Domain of electronic mail service"; 
$LANG['setup'][800]="Mysql replikere"; 
$LANG['setup'][801]="Enable the MySQL replicate"; 
$LANG['setup'][802]="Database"; 
$LANG['setup'][803]="Forskjellen mellom master og slave"; 
$LANG['setup'][806]="Max delay between master and slave (minutes)"; 
$LANG['setup'][807]="The slave base is desynchronized. The difference is of:"; 
$LANG['setup'][808]="Slave databasen ikke synkronisert!"; 
$LANG['setup'][809]="MySQL kopi: skrivebeskyttet"; 
$LANG['setup'][810]="Desynchronization MySQL replication"; 

$LANG['software'][1]="Kjøp versjon"; 
$LANG['software'][2]="Bruk versjon"; 
$LANG['software'][3]="Not installed affected licenses"; 
$LANG['software'][4]="Ubegrenset"; 
$LANG['software'][5]="Versjoner"; 
$LANG['software'][6]="Publisher"; 
$LANG['software'][7]="Legg til en versjon"; 
$LANG['software'][8]="Legg til en lisens"; 
$LANG['software'][11]="Lisenser"; 
$LANG['software'][17]="Installert programvare"; 
$LANG['software'][19]="Installasjoner"; 
$LANG['software'][20]="Resterende"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Oppdatering"; 
$LANG['software'][30]="Type lisenser"; 
$LANG['software'][32]="Utløp"; 
$LANG['software'][44]="Installer programvaren"; 
$LANG['software'][45]="Avinstaller programvare"; 
$LANG['software'][46]="Associable to a ticket"; 
$LANG['software'][47]="Sammenslåing"; 
$LANG['software'][48]="Sammenslå"; 
$LANG['software'][49]="Programmvare lagt i papirkurven etter sammenslåing"; 
$LANG['software'][50]="Tilordnet til datamaskinen"; 
$LANG['software'][51]="Nummeret skal være 1 for å kunne påvirke"; 

$LANG['softwarecategories'][2]="Uncategorized software"; 
$LANG['softwarecategories'][3]="Unfold the software without category"; 
$LANG['softwarecategories'][4]="Unfold the software belonging to a category"; 
$LANG['softwarecategories'][5]="Kategori programvare"; 

$LANG['state'][0]="Status"; 
$LANG['state'][6]="Element type"; 
$LANG['state'][7]="Ingen elementer funnet"; 
$LANG['state'][11]="Oppsummering"; 

$LANG['stats'][0]="Velg statistikk som skal vises"; 
$LANG['stats'][1]="Global"; 
$LANG['stats'][2]="No item to display"; 
$LANG['stats'][3]="Av elementet"; 
$LANG['stats'][5]="Number of opened tickets"; 
$LANG['stats'][6]="Gjennomsnitts oppløsning forsinkelse"; 
$LANG['stats'][7]="Show graphics"; 
$LANG['stats'][11]="Antall løste oppgaver"; 
$LANG['stats'][13]="Antall oppgaver"; 
$LANG['stats'][15]="Gjennomsnitts oppløsning forsinkelse"; 
$LANG['stats'][16]="Tekniker navn"; 
$LANG['stats'][20]="Brukernavn"; 
$LANG['stats'][23]="Ingen statistikk er tilgjengelig"; 
$LANG['stats'][25]="Gjennomsnitts (Virkelig) varighet av oppgaven"; 
$LANG['stats'][27]="Totalt (ekte) varighet av oppgaven"; 
$LANG['stats'][30]="Gjennomsnittlig forsinkelse til å svare på oppgaven"; 
$LANG['stats'][31]="Dag(er)"; 
$LANG['stats'][33]="Minutt(er)"; 
$LANG['stats'][34]="Sekund(er)"; 
$LANG['stats'][35]="Oppgave(r)"; 
$LANG['stats'][44]="Levrandør navn"; 
$LANG['stats'][45]="Av maskinvare"; 
$LANG['stats'][47]="Av oppgaver"; 
$LANG['stats'][48]="(tildelt)"; 
$LANG['stats'][49]="(oppfølging)"; 

$LANG['title'][5]="Kunnskapsdatabase"; 
$LANG['title'][6]="Nettverk"; 
$LANG['title'][9]="Element Status"; 
$LANG['title'][10]="Oppgave oppfølging"; 
$LANG['title'][13]="Brukerinformasjon"; 
$LANG['title'][14]="Eksterne godkjente kilder"; 
$LANG['title'][24]="Assistanse"; 
$LANG['title'][26]="Hovedsaklig"; 
$LANG['title'][27]="Tilkoblinger"; 
$LANG['title'][28]="Oppgaver"; 
$LANG['title'][30]="Komponenter"; 
$LANG['title'][33]="Eksterne lenker"; 
$LANG['title'][34]="Koblinger"; 
$LANG['title'][37]="Notater"; 
$LANG['title'][38]="Historisk"; 
$LANG['title'][40]="Offentlige og personlige notater"; 
$LANG['title'][42]="Massive endringer"; 
$LANG['title'][43]="Register"; 

$LANG['tracking'][1]="Mine enheter"; 
$LANG['tracking'][2]="Eller fullfør søket"; 
$LANG['tracking'][3]="Ugyldige datoer. Oppdatering avbrutt."; 
$LANG['tracking'][4]="There is no urgency in your ticket, please correct."; 
$LANG['tracking'][8]="Ingen beskrivelse for billetten, vennligst prøv igjen."; 
$LANG['tracking'][9]="Default for tickets"; 
$LANG['tracking'][10]="Default for mail recipients"; 
$LANG['tracking'][24]="Dokument sertifikat"; 
$LANG['tracking'][29]="Nummer"; 
$LANG['tracking'][30]="Ny"; 
$LANG['tracking'][31]="Bearbeider (tildelte)"; 
$LANG['tracking'][32]="Bearbeider (planlagt)"; 
$LANG['tracking'][34]="Direkte"; 
$LANG['tracking'][35]="Skrevet / Skriftelig"; 
$LANG['tracking'][37]="Hold oppgaver når purging maskinvare i beholdningen"; 
$LANG['tracking'][38]="En e-mail var sendt til"; 
$LANG['tracking'][39]="Visible in the simplified interface"; 

$LANG['transfer'][1]="Overføring"; 
$LANG['transfer'][3]="Hvis ikke i bruk"; 
$LANG['transfer'][4]="Hvis du vil tømme listen over elementer som skal overføres"; 
$LANG['transfer'][5]="Du kan fortsette å legge til elementer som skal overføres eller overføre som nå disse elementene"; 
$LANG['transfer'][6]="Tenk på å lage en sikkerhetskopi før du overfører elementer."; 
$LANG['transfer'][7]="Elementene som skal overføres"; 
$LANG['transfer'][8]="Overføringsmodus"; 

$LANG['update'][88]="The version of the database is not compatible with the version of the installed files. An update is necessary."; 
$LANG['update'][89]="You are trying to use GLPI with files from an earlier version to the version of the database. Please install the files corresponding to the version of your database."; 
$LANG['update'][90]="Feil under oppdatering av databasen"; 
$LANG['update'][91]="Advarsel!"; 
$LANG['update'][92]="Du vil oppdatere GLPI database som heter:"; 
$LANG['update'][93]="Databasen tilkoblingen er vellykket"; 
$LANG['update'][94]="Oppdateringen er vellykket, databasen din er nå oppdatert"; 
$LANG['update'][95]="Tilkoblingen til databasen mislyktes. Kontroller tilkoblings statistikkene inkludert i config_db.php filen"; 
$LANG['update'][96]="Nå har alle administratorer super admin rettigheter. Denne nye brukertypen ble lagt til."; 
$LANG['update'][105]="Umulig å få en oppdatering på denne måten!!"; 
$LANG['update'][106]="Gå tilbake til GLPI"; 
$LANG['update'][107]="Du må nå fortsette og oppdatere innholdet i databasen"; 
$LANG['update'][130]="Plasserings oppdatering"; 
$LANG['update'][131]="Den nye strukturen er nå rangsordnet"; 
$LANG['update'][132]="Hvis du brukte et skilleskråstrek tegn, kan du sette det i rekkefølge til og automatisere utviklingen av den nye rangsordningen."; 
$LANG['update'][133]="Du kan også angi en rotplassering som vil omfatte alle de genererte stedene."; 
$LANG['update'][134]="Skilleskråstreks tegn"; 
$LANG['update'][135]="Rotplasseringen"; 
$LANG['update'][136]="Dette er den nye rangsordningen, hvis den er OK, kan du bekrefte dette."; 
$LANG['update'][137]="Ny rangsordning"; 
$LANG['update'][138]="Reelle steder"; 
$LANG['update'][139]="Tabeller optimaliseringsforespørsel"; 
$LANG['update'][140]="Creating indexes"; 
$LANG['update'][141]="Change of the database layout"; 
$LANG['update'][142]="Data migration"; 

$LANG['users'][1]="Tittel"; 
$LANG['users'][2]="Kategori"; 

$LANG['validation'][0]="Approval"; 
$LANG['validation'][1]="Send a Approval request"; 
$LANG['validation'][2]="Status"; 
$LANG['validation'][3]="Request date"; 
$LANG['validation'][4]="Approval date"; 
$LANG['validation'][5]="Request comment"; 
$LANG['validation'][6]="Approval comment"; 
$LANG['validation'][7]="Approval(s) for the ticket"; 
$LANG['validation'][9]="Waiting for approval"; 
$LANG['validation'][10]="Refused"; 
$LANG['validation'][11]="Granted"; 
$LANG['validation'][12]="Not subject to approval"; 
$LANG['validation'][13]="Approval request send to"; 
$LANG['validation'][15]="Ticket waiting for your Approval"; 
$LANG['validation'][16]="Optional when approved"; 
$LANG['validation'][18]="Approval requester"; 
$LANG['validation'][19]="Approval granted"; 
$LANG['validation'][20]="Approval denied"; 
$LANG['validation'][21]="Approver"; 
$LANG['validation'][23]="The selected user has no valid emailaddress. The request has been created, without email confirmation."; 
$LANG['validation'][26]="Approval request"; 
$LANG['validation'][27]="An approval request has been submitted"; 
$LANG['validation'][28]="Status of the Approval request"; 
$LANG['validation'][29]="If approval is denied, specify a reason"; 
$LANG['validation'][30]="Cancel the approval request to"; 
$LANG['validation'][31]="Update the Approval request to"; 
$LANG['validation'][32]="An answer to a Approval request was produced"; 
$LANG['validation'][33]="Tickets awaiting approval"; 
?>